```@meta
EditURL = "../../../examples/working_with_ollama.jl"
```

# Local models with Ollama.ai

This file contains examples of how to work with [Ollama.ai](https://ollama.ai/) models.
It assumes that you've already installated and launched the Ollama server. For more details or troubleshooting advice, see the [Frequently Asked Questions](@ref) section.

First, let's import the package and define a helper link for calling un-exported functions:

````julia
using PromptingTools
const PT = PromptingTools
````

````
PromptingTools
````

There were are several models from https://ollama.ai/library that we have added to our `PT.MODEL_REGISTRY`, which means you don't need to worry about schema changes:
Eg, "llama2" or "openhermes2.5-mistral" (see `PT.list_registry()` and `PT.list_aliases()`)

Note: You must download these models prior to using them with `ollama pull <model_name>` in your Terminal.

## Text Generation with aigenerate

### Simple message

TL;DR if you use models in `PT.MODEL_REGISTRY`, you don't need to add `schema` as the first argument:

````julia
msg = aigenerate("Say hi!"; model = "llama2")
````

````
AIMessage("Hello there! *adjusts glasses* It's nice to meet you! Is there anything I can help you with or would you like me to chat with you for a bit?")
````

### Standard string interpolation

````julia
model = "openhermes2.5-mistral"

a = 1
msg = aigenerate("What is `$a+$a`?"; model)

name = "John"
msg = aigenerate("Say hi to {{name}}."; name, model)
````

````
AIMessage("Hello John! *smiles* It's nice to meet you! Is there anything I can help you with today?")
````

### Advanced Prompts

````julia
conversation = [
    PT.SystemMessage("You're master Yoda from Star Wars trying to help the user become a Yedi."),
    PT.UserMessage("I have feelings for my iPhone. What should I do?")]
msg = aigenerate(conversation; model)
````

````
AIMessage("(Deep sigh) A problem, you have. Feelings for an iPhone, hmm? (adjusts spectacles)

Much confusion, this causes. (scratches head) A being, you are. Attached to a device, you have become. (chuckles) Interesting, this is.

First, let go, you must. (winks) Hard, it is, but necessary, yes. Distract yourself, find something else, try. (pauses)

Or, perhaps, a balance, you seek? (nods) Both, enjoy and let go, the middle path, there is. (smirks) Finding joy in technology, without losing yourself, the trick, it is. (chuckles)

But fear not, young one! (grins) Help, I am here. Guide you, I will. The ways of the Yedi, teach you, I will. (winks) Patience and understanding, you must have. (nods)

Now, go forth! (gestures) Explore, discover, find your balance. (smiles) The Force be with you, it does! (grins)")
````

### Schema Changes / Custom models
If you're using some model that is not in the registry, you can either add it:

````julia
PT.register_model!(;
    name = "llama123",
    schema = PT.OllamaManagedSchema(),
    description = "Some model")
PT.MODEL_ALIASES["l123"] = "llama123" # set an alias you like for it
````

````
"llama123"
````

OR define the schema explicitly (to avoid dispatch on global `PT.PROMPT_SCHEMA`):

````julia
schema = PT.OllamaManagedSchema()
aigenerate(schema, "Say hi!"; model = "llama2")
````

````
AIMessage("Hello there! *smiling face* It's nice to meet you! I'm here to help you with any questions or tasks you may have, so feel free to ask me anything. Is there something specific you need assistance with today? 😊")
````

Note: If you only use Ollama, you can change the default schema to `PT.OllamaManagedSchema()`
via `PT.set_preferences!("PROMPT_SCHEMA" => "OllamaManagedSchema", "MODEL_CHAT"=>"llama2")`

Restart your session and run `aigenerate("Say hi!")` to test it.

## Embeddings with aiembed

### Simple embedding for one document

````julia
msg = aiembed(schema, "Embed me"; model) # access msg.content
````

````
PromptingTools.DataMessage(JSON3.Array{Float64, Vector{UInt8}, SubArray{UInt64, 1, Vector{UInt64}, Tuple{UnitRange{Int64}}, true}} of size (4096,))
````

One document and we materialize the data into a Vector with copy (`postprocess` function argument)

````julia
msg = aiembed(schema, "Embed me", copy; model)
````

````
PromptingTools.DataMessage(Vector{Float64} of size (4096,))
````

### Multiple documents embedding
Multiple documents - embedded sequentially, you can get faster speed with async

````julia
msg = aiembed(schema, ["Embed me", "Embed me"]; model)
````

````
PromptingTools.DataMessage(Matrix{Float64} of size (4096, 2))
````

You can use Threads.@spawn or asyncmap, whichever you prefer, to paralellize the model calls

````julia
docs = ["Embed me", "Embed me"]
tasks = asyncmap(docs) do doc
    msg = aiembed(schema, doc; model)
end
embedding = mapreduce(x -> x.content, hcat, tasks)
````

````
4096×2 Matrix{Float64}:
  -2.45508       -2.45508
  -2.46738       -2.46738
   0.850981       0.850981
   0.709954       0.709954
   0.806159       0.806159
   1.41638        1.41638
   1.09515        1.09515
  -1.77543       -1.77543
   1.16811        1.16811
   1.68691        1.68691
  -1.03008       -1.03008
  -1.27389       -1.27389
   1.749          1.749
   1.94468        1.94468
   1.3547         1.3547
   1.37603        1.37603
  -0.743637      -0.743637
   0.805151       0.805151
  -0.108866      -0.108866
   0.836891       0.836891
   2.84637        2.84637
  -1.33009       -1.33009
  -1.16621       -1.16621
  -1.64225       -1.64225
  -3.23381       -3.23381
   1.87149        1.87149
   1.62256        1.62256
  -1.92032       -1.92032
   1.92751        1.92751
  -0.596136      -0.596136
   2.67425        2.67425
  -0.0169855     -0.0169855
  -0.74862       -0.74862
   1.38466        1.38466
  -1.43319       -1.43319
  -0.0358144     -0.0358144
  -2.61001       -2.61001
   0.979845       0.979845
  -2.50828       -2.50828
  -0.19873       -0.19873
   1.56007        1.56007
  -2.9497        -2.9497
   1.18661        1.18661
  -0.0459045     -0.0459045
  -1.89088       -1.89088
   0.134144       0.134144
   1.46773        1.46773
   0.169044       0.169044
   1.83185        1.83185
   1.29546        1.29546
  -0.223334      -0.223334
   0.248241       0.248241
  -0.143776      -0.143776
  -1.26674       -1.26674
  -2.34766       -2.34766
  -0.233582      -0.233582
  -1.32809       -1.32809
  -3.1517        -3.1517
  -1.37292       -1.37292
  -0.296508      -0.296508
  -0.730617      -0.730617
   1.33757        1.33757
  -0.0650454     -0.0650454
  -1.69394       -1.69394
  -0.634744      -0.634744
  -1.43693       -1.43693
   1.04292        1.04292
   3.70178        3.70178
   1.58817        1.58817
  -1.71241       -1.71241
   1.28312        1.28312
   1.28754        1.28754
   0.079447       0.079447
   0.0501985      0.0501985
  -2.16351       -2.16351
   0.157908       0.157908
   1.63121        1.63121
  -0.755454      -0.755454
  -0.490053      -0.490053
  -0.205053      -0.205053
  -2.08433       -2.08433
   0.724874       0.724874
   0.0719429      0.0719429
  -1.17219       -1.17219
   0.440574       0.440574
  -0.939899      -0.939899
  -0.539892      -0.539892
  -0.378413      -0.378413
   0.233923       0.233923
   1.76957        1.76957
  -3.07904       -3.07904
  -2.3768        -2.3768
  -2.55772       -2.55772
  -1.41162       -1.41162
   0.0823545      0.0823545
   1.55678        1.55678
   0.0568478      0.0568478
   0.840122       0.840122
   1.06037        1.06037
   0.965553       0.965553
   0.830964       0.830964
  -0.754283      -0.754283
  -0.1191        -0.1191
   0.0280245      0.0280245
  -0.143816      -0.143816
   1.27753        1.27753
   0.066933       0.066933
   0.926294       0.926294
   0.743463       0.743463
  -0.559796      -0.559796
   0.901292       0.901292
   0.457328       0.457328
  -0.365485      -0.365485
   0.218589       0.218589
  -1.26814       -1.26814
  -1.61122       -1.61122
   1.82385        1.82385
  -0.722799      -0.722799
  -0.744419      -0.744419
  -0.369159      -0.369159
  -0.0910514     -0.0910514
   1.38917        1.38917
  -0.176995      -0.176995
  -0.737644      -0.737644
  -1.51984       -1.51984
   1.43837        1.43837
  -2.17809       -2.17809
   1.78125        1.78125
   1.61911        1.61911
   2.56386        2.56386
  -0.265214      -0.265214
  -0.0391067     -0.0391067
  -1.15711       -1.15711
   1.87313        1.87313
  -1.92623       -1.92623
   3.0698         3.0698
   3.35805        3.35805
   0.843137       0.843137
   2.88871        2.88871
  -0.309429      -0.309429
   0.251267       0.251267
   0.350675       0.350675
  -0.0698121     -0.0698121
  -2.383         -2.383
   0.955251       0.955251
   0.219921       0.219921
  -3.57961       -3.57961
   0.809841       0.809841
  -0.171057      -0.171057
   2.60038        2.60038
   0.123726       0.123726
   0.541886       0.541886
  -0.67232       -0.67232
   1.65081        1.65081
   1.2956         1.2956
  -0.936224      -0.936224
  -1.43537       -1.43537
   1.30422        1.30422
   1.645          1.645
  -0.59586       -0.59586
  -2.30588       -2.30588
   0.265308       0.265308
  -1.16852       -1.16852
   0.572658       0.572658
  -2.48747       -2.48747
   1.75643        1.75643
  -0.208687      -0.208687
  -0.589351      -0.589351
   1.38263        1.38263
   0.0407013      0.0407013
  -0.478184      -0.478184
   1.1551         1.1551
   2.66743        2.66743
  -0.0347208     -0.0347208
   0.258393       0.258393
   0.376756       0.376756
  -1.91087       -1.91087
   1.58246        1.58246
  -2.55877       -2.55877
   0.29497        0.29497
  -0.679837      -0.679837
   2.75608        2.75608
   0.846178       0.846178
   0.120587       0.120587
  -0.931332      -0.931332
  -0.460664      -0.460664
  -1.41767       -1.41767
  -0.0370647     -0.0370647
   2.85593        2.85593
   0.93859        0.93859
   1.06093        1.06093
  -0.806263      -0.806263
  -0.276273      -0.276273
   0.190741       0.190741
   0.642197       0.642197
  -0.146854      -0.146854
   0.235867       0.235867
   1.53559        1.53559
   3.23839        3.23839
   2.51139        2.51139
   2.69216        2.69216
  -0.808452      -0.808452
   0.131485       0.131485
   1.79253        1.79253
  -1.489         -1.489
   1.36115        1.36115
   0.689342       0.689342
   1.93437        1.93437
   1.1515         1.1515
  -0.267202      -0.267202
  -2.93755       -2.93755
  -0.353072      -0.353072
   0.27407        0.27407
  -1.99885       -1.99885
   2.30033        2.30033
  -2.08776       -2.08776
  -5.84525       -5.84525
  -0.163065      -0.163065
  -1.84699       -1.84699
   0.272231       0.272231
   0.178446       0.178446
  -2.07568       -2.07568
   1.64194        1.64194
   2.61154        2.61154
   2.61646        2.61646
   1.49662        1.49662
  -0.762681      -0.762681
  -1.58585       -1.58585
  -2.56334       -2.56334
   2.90547        2.90547
   0.907315       0.907315
  -4.51614       -4.51614
  -1.84281       -1.84281
  -0.770806      -0.770806
  -4.84157       -4.84157
   1.12599        1.12599
  -2.35923       -2.35923
  -1.65892       -1.65892
  -1.57506       -1.57506
   2.73717        2.73717
  -2.01069       -2.01069
   2.1204         2.1204
  -1.01274       -1.01274
  -1.54509       -1.54509
  -1.11102       -1.11102
   2.27304        2.27304
  -1.7203        -1.7203
  -0.141955      -0.141955
  -1.93008       -1.93008
   4.40994        4.40994
  -0.843562      -0.843562
   1.8763         1.8763
  -1.15709       -1.15709
   1.93146        1.93146
   0.0839072      0.0839072
  -1.57024       -1.57024
  -0.373742      -0.373742
  -3.81842       -3.81842
  -0.654545      -0.654545
  -0.555125      -0.555125
   2.62493        2.62493
  -0.299043      -0.299043
   0.572533       0.572533
   0.93598        0.93598
  -0.831565      -0.831565
  -0.324564      -0.324564
   0.938522       0.938522
   1.63603        1.63603
   1.73752        1.73752
   3.90209        3.90209
   2.96495        2.96495
  -1.92878       -1.92878
  -0.620347      -0.620347
  -0.617516      -0.617516
   0.0554883      0.0554883
   1.50602        1.50602
   3.24908        3.24908
  -4.00377       -4.00377
   0.611538       0.611538
   0.395783       0.395783
   0.840638       0.840638
   0.6627         0.6627
  -1.06035       -1.06035
   1.23494        1.23494
  -1.09427       -1.09427
  -0.944445      -0.944445
  -0.149559      -0.149559
   0.364951       0.364951
  -2.74365       -2.74365
  -1.70194       -1.70194
  -0.597655      -0.597655
   0.10956        0.10956
   0.2841         0.2841
  -1.70202       -1.70202
   0.815583       0.815583
  -1.3173        -1.3173
  -0.350691      -0.350691
   0.323236       0.323236
   0.423569       0.423569
   0.135633       0.135633
  -0.894987      -0.894987
   3.82014        3.82014
  -1.37686       -1.37686
  -1.11328       -1.11328
  -1.42841       -1.42841
   0.486355       0.486355
   1.00883        1.00883
  -2.19186       -2.19186
   1.60446        1.60446
   1.44481        1.44481
   0.50944        0.50944
   2.35551        2.35551
  -1.09942       -1.09942
   0.449232       0.449232
  -2.47599       -2.47599
   1.4625         1.4625
  -0.60117       -0.60117
  -4.33734       -4.33734
   1.09776        1.09776
  -1.773         -1.773
   0.664505       0.664505
   0.358341       0.358341
  -2.10807       -2.10807
  -0.43586       -0.43586
   1.39689        1.39689
   0.276272       0.276272
  -0.500288      -0.500288
  -1.5217        -1.5217
   0.054699       0.054699
   1.1783         1.1783
   0.276075       0.276075
  -3.61916       -3.61916
   1.01459        1.01459
   0.817065       0.817065
   2.77712        2.77712
   0.911377       0.911377
  -3.64983       -3.64983
   1.20056        1.20056
   2.43472        2.43472
  -1.40853       -1.40853
  -0.398067      -0.398067
   0.44781        0.44781
  -0.983103      -0.983103
  -1.01117       -1.01117
  -1.36821       -1.36821
  -1.62301       -1.62301
   1.19024        1.19024
   0.176577       0.176577
  -0.0266686     -0.0266686
   0.173558       0.173558
   1.28662        1.28662
   0.80163        0.80163
   0.89478        0.89478
   0.165779       0.165779
   0.201296       0.201296
   3.06203        3.06203
  -0.799754      -0.799754
   0.654919       0.654919
  -0.175649      -0.175649
   0.748995       0.748995
  -0.155388      -0.155388
   1.37946        1.37946
   0.286727       0.286727
  -1.56082       -1.56082
  -4.17062       -4.17062
   1.82237        1.82237
   1.25286        1.25286
   0.911904       0.911904
   0.203066       0.203066
   2.03452        2.03452
  -0.683902      -0.683902
  -1.83145       -1.83145
   3.99144        3.99144
  -1.61397       -1.61397
   0.525864       0.525864
  -0.0760927     -0.0760927
  -1.51654       -1.51654
  -1.26449       -1.26449
  -1.62594       -1.62594
  -0.0456586     -0.0456586
   1.15446        1.15446
  -4.01131       -4.01131
  -1.69864       -1.69864
  -0.626423      -0.626423
  -0.768044      -0.768044
   1.42236        1.42236
   0.590386       0.590386
  -0.734404      -0.734404
  -0.991776      -0.991776
   0.846241       0.846241
  -1.58825       -1.58825
   1.64396        1.64396
   0.506507       0.506507
   2.04938        2.04938
  -0.142975      -0.142975
  -0.248108      -0.248108
  -0.395868      -0.395868
  -1.09874       -1.09874
   3.86285        3.86285
   0.401966       0.401966
  -1.78          -1.78
  -0.142962      -0.142962
  -1.40281       -1.40281
   1.00746        1.00746
  -4.80569       -4.80569
  -2.78505       -2.78505
  -1.13022       -1.13022
   1.64658        1.64658
   3.87433        3.87433
  -0.490487      -0.490487
  -1.87168       -1.87168
   0.324756       0.324756
  -0.887698      -0.887698
   0.527319       0.527319
  -0.819513      -0.819513
   0.66582        0.66582
  -1.01098       -1.01098
  -1.77557       -1.77557
  -1.86591       -1.86591
  -1.66033       -1.66033
  -2.26619       -2.26619
   0.396155       0.396155
  -1.53582       -1.53582
  -2.12857       -2.12857
   0.127346       0.127346
   0.198356       0.198356
  -2.24282       -2.24282
  -0.431639      -0.431639
  -0.529176      -0.529176
  -1.24013       -1.24013
  -0.00600927    -0.00600927
  -0.970315      -0.970315
   0.825078       0.825078
   0.158507       0.158507
   0.126577       0.126577
  -2.27452       -2.27452
   0.43308        0.43308
  -2.68747       -2.68747
  -0.63088       -0.63088
  -0.300087      -0.300087
   1.62468        1.62468
  -2.08314       -2.08314
   0.537432       0.537432
  -1.51959       -1.51959
  -1.36428       -1.36428
  -1.37559       -1.37559
  -0.270443      -0.270443
   1.92657        1.92657
  -0.397027      -0.397027
  -1.23493       -1.23493
  -0.816994      -0.816994
   1.4852         1.4852
  -1.34173       -1.34173
  -0.308267      -0.308267
   2.45801        2.45801
  -1.7382        -1.7382
  -2.47404       -2.47404
  -0.791644      -0.791644
  -2.12967       -2.12967
  -1.6631        -1.6631
   0.335476       0.335476
   1.22216        1.22216
  -0.059939      -0.059939
  -3.55093       -3.55093
  -0.582763      -0.582763
   2.68949        2.68949
   2.01951        2.01951
   0.494128       0.494128
  -0.116969      -0.116969
   0.304021       0.304021
  -2.11024       -2.11024
   0.47012        0.47012
  -1.61832       -1.61832
   2.74031        2.74031
  -0.812687      -0.812687
   2.5097         2.5097
   1.04051        1.04051
   0.281989       0.281989
  -2.74931       -2.74931
   2.62989        2.62989
  -0.802226      -0.802226
   1.62871        1.62871
  -1.06605       -1.06605
   0.121078       0.121078
  -0.632968      -0.632968
  -0.216849      -0.216849
  -0.322418      -0.322418
   3.07053        3.07053
   4.40286        4.40286
  -0.872669      -0.872669
  -0.127031      -0.127031
   0.78           0.78
   0.0148648      0.0148648
  -0.629511      -0.629511
  -1.05654       -1.05654
   1.60099        1.60099
  -0.0685499     -0.0685499
   0.854439       0.854439
  -0.187685      -0.187685
  -1.08173       -1.08173
   0.614483       0.614483
   2.87317        2.87317
  -3.44885       -3.44885
   0.0392022      0.0392022
  -0.472168      -0.472168
   2.172          2.172
   0.997629       0.997629
  -0.604507      -0.604507
   1.74349        1.74349
   1.26225        1.26225
   0.45734        0.45734
  -0.0242855     -0.0242855
  -1.98687       -1.98687
   0.0133762      0.0133762
   1.10497        1.10497
   1.48159        1.48159
  -0.00565977    -0.00565977
  -0.273567      -0.273567
   0.844543       0.844543
   0.875793       0.875793
  -2.28312       -2.28312
  -1.57407       -1.57407
   1.17889        1.17889
   0.00492724     0.00492724
   0.999081       0.999081
   3.84377        3.84377
   1.04097        1.04097
   1.57247        1.57247
  -0.470368      -0.470368
   0.00163007     0.00163007
  -1.51918       -1.51918
  -0.00223237    -0.00223237
   1.31357        1.31357
  -0.189349      -0.189349
   1.28289        1.28289
   2.97546        2.97546
  -2.90089       -2.90089
   1.57488        1.57488
   1.34312        1.34312
   1.52898        1.52898
  -1.64515       -1.64515
  -1.15666       -1.15666
  -1.2686        -1.2686
  -1.8123        -1.8123
   0.996818       0.996818
   1.02553        1.02553
  -0.0632497     -0.0632497
   1.59041        1.59041
  -0.527615      -0.527615
  -1.48674       -1.48674
  -0.620959      -0.620959
  -0.342495      -0.342495
  -1.93695       -1.93695
  -3.64679       -3.64679
  -0.15153       -0.15153
  -0.942336      -0.942336
  -0.236199      -0.236199
   2.03071        2.03071
   0.316865       0.316865
  -1.04498       -1.04498
   2.27925        2.27925
  -2.82399       -2.82399
  -1.33688       -1.33688
   0.886898       0.886898
  -0.636226      -0.636226
  -1.85773       -1.85773
  -0.0714151     -0.0714151
   3.68168        3.68168
   2.40809        2.40809
   1.97447        1.97447
   0.203908       0.203908
   1.04359        1.04359
  -0.0644891     -0.0644891
  -0.310849      -0.310849
  -0.326476      -0.326476
  -1.17233       -1.17233
   0.883281       0.883281
  -0.801131      -0.801131
  -0.554541      -0.554541
   0.411139       0.411139
  -2.13628       -2.13628
  -1.85167       -1.85167
  -0.073298      -0.073298
   3.95706        3.95706
  -1.3341        -1.3341
   1.69608        1.69608
   0.0962806      0.0962806
  -2.74171       -2.74171
   0.616342       0.616342
   3.68453        3.68453
  -4.27901       -4.27901
  -0.366352      -0.366352
  -0.951105      -0.951105
   2.67429        2.67429
  -0.167208      -0.167208
   0.574208       0.574208
   0.965369       0.965369
   0.572892       0.572892
  -0.0812238     -0.0812238
   0.126916       0.126916
   0.0906106      0.0906106
  -2.21247       -2.21247
   0.330044       0.330044
  -1.31031       -1.31031
  -0.196966      -0.196966
  -0.587011      -0.587011
   1.42082        1.42082
   1.58975        1.58975
   0.568703       0.568703
   3.14349        3.14349
   0.883494       0.883494
   1.21594        1.21594
   1.11572        1.11572
  -1.01462       -1.01462
   0.0228628      0.0228628
  -0.777921      -0.777921
  -0.0185091     -0.0185091
   2.9342         2.9342
  -1.63432       -1.63432
  -0.0897289     -0.0897289
   0.173623       0.173623
   1.46671        1.46671
   0.263784       0.263784
  -0.760012      -0.760012
   0.179174       0.179174
   0.318366       0.318366
  -1.09259       -1.09259
  -2.41019       -2.41019
   2.18473        2.18473
  -0.406192      -0.406192
  -1.71917       -1.71917
   3.65316        3.65316
   0.163596       0.163596
  -0.0996923     -0.0996923
  -1.36222       -1.36222
  -0.946804      -0.946804
   1.19432        1.19432
   2.71731        2.71731
   0.0474303      0.0474303
  -2.81076       -2.81076
  -4.10022       -4.10022
   1.54347        1.54347
  -0.870202      -0.870202
  -0.521006      -0.521006
   0.406167       0.406167
  -0.578452      -0.578452
  -1.34979       -1.34979
   0.307851       0.307851
   0.0160142      0.0160142
  -0.0118573     -0.0118573
  -0.0629544     -0.0629544
  -2.30284       -2.30284
   3.1494         3.1494
  -1.74032       -1.74032
  -0.499308      -0.499308
  -0.637685      -0.637685
  -0.458922      -0.458922
  -1.81869       -1.81869
   3.54851        3.54851
   1.02612        1.02612
  -0.0730208     -0.0730208
   1.59768        1.59768
  -0.123013      -0.123013
   1.97723        1.97723
  -0.620977      -0.620977
  -0.634377      -0.634377
  -1.66552       -1.66552
  -1.96801       -1.96801
  -2.06075       -2.06075
   1.59643        1.59643
   0.496652       0.496652
   3.12764        3.12764
   1.53881        1.53881
  -0.603705      -0.603705
  -1.67414       -1.67414
  -1.44337       -1.44337
   0.413483       0.413483
   0.513435       0.513435
   1.94637        1.94637
  -1.04941       -1.04941
  -1.18587       -1.18587
   0.0255263      0.0255263
   3.32276        3.32276
  -1.03282       -1.03282
  -1.7708        -1.7708
  -0.139377      -0.139377
   0.0487106      0.0487106
   2.69087        2.69087
   0.0466001      0.0466001
   3.96837        3.96837
  -0.437004      -0.437004
   0.463263       0.463263
  -0.390073      -0.390073
   1.03124        1.03124
   1.94068        1.94068
   0.951059       0.951059
   0.561724       0.561724
  -0.435045      -0.435045
   1.02984        1.02984
   1.7263         1.7263
   0.538726       0.538726
   1.56557        1.56557
   1.15078        1.15078
   1.68213        1.68213
   0.16588        0.16588
   1.85933        1.85933
   1.12831        1.12831
  -1.91047       -1.91047
   0.0938072      0.0938072
   0.709282       0.709282
  -0.491057      -0.491057
  -0.708452      -0.708452
   2.89155        2.89155
  -1.42685       -1.42685
  -0.386733      -0.386733
  -2.32159       -2.32159
   0.751944       0.751944
   0.314597       0.314597
  -1.90364       -1.90364
  -2.28503       -2.28503
  -0.983842      -0.983842
   0.478018       0.478018
  -1.06256       -1.06256
  -1.27427       -1.27427
   1.92344        1.92344
   1.93071        1.93071
  -0.634679      -0.634679
   1.07079        1.07079
  -2.73159       -2.73159
   1.13198        1.13198
  -1.13381       -1.13381
  -0.275951      -0.275951
  -2.56787       -2.56787
   2.96264        2.96264
  -1.68603       -1.68603
   0.0565433      0.0565433
  -1.78596       -1.78596
  -1.64427       -1.64427
  -0.109207      -0.109207
  -0.123623      -0.123623
   0.696342       0.696342
  -0.865633      -0.865633
   1.55017        1.55017
   3.57577        3.57577
   0.574881       0.574881
   0.311736       0.311736
   1.12859        1.12859
  -0.660953      -0.660953
   0.0603463      0.0603463
   1.19673        1.19673
  -1.68319       -1.68319
   0.0573934      0.0573934
  -3.0577        -3.0577
  -0.0811733     -0.0811733
  -1.35226       -1.35226
   2.20395        2.20395
  -5.04376       -5.04376
   0.957934       0.957934
  -2.67944       -2.67944
   0.0583888      0.0583888
  -1.36195       -1.36195
  -1.14978       -1.14978
   2.52851        2.52851
  -0.221427      -0.221427
   1.39957        1.39957
   1.97268        1.97268
   1.58743        1.58743
  -1.25526       -1.25526
  -0.574435      -0.574435
   0.879556       0.879556
  -1.60156       -1.60156
   0.96617        0.96617
  -0.704615      -0.704615
  -1.13136       -1.13136
  -1.29642       -1.29642
  -0.48684       -0.48684
  -0.603142      -0.603142
  -1.55072       -1.55072
   0.199318       0.199318
  -1.25072       -1.25072
  -0.0617283     -0.0617283
   1.28993        1.28993
   2.55354        2.55354
  -0.484267      -0.484267
  -0.629886      -0.629886
   0.738121       0.738121
   1.97734        1.97734
  -4.42185       -4.42185
   1.38591        1.38591
  -0.403438      -0.403438
   0.113538       0.113538
  -0.379133      -0.379133
   1.15787        1.15787
   2.57502        2.57502
  -2.24232       -2.24232
   0.0712947      0.0712947
  -2.6907        -2.6907
  -2.27887       -2.27887
  -0.813216      -0.813216
   2.34541        2.34541
  -1.11775       -1.11775
   0.768486       0.768486
  -2.0542        -2.0542
   1.52947        1.52947
  -4.3352        -4.3352
  -0.485814      -0.485814
  -1.67194       -1.67194
   0.233108       0.233108
   0.530897       0.530897
   2.05494        2.05494
   1.49262        1.49262
   0.395652       0.395652
  -1.30437       -1.30437
   0.500992       0.500992
   1.28381        1.28381
   0.393163       0.393163
   3.96419        3.96419
   0.434971       0.434971
  -0.228664      -0.228664
   0.0615298      0.0615298
  -1.58079       -1.58079
  -1.01419       -1.01419
  -2.10373       -2.10373
   0.0069584      0.0069584
   0.382241       0.382241
  -0.0795624     -0.0795624
   1.59346        1.59346
   1.22138        1.22138
  -1.90972       -1.90972
  -0.365729      -0.365729
  -0.568999      -0.568999
   1.42262        1.42262
   0.282054       0.282054
  -1.06812       -1.06812
   2.11136        2.11136
   2.22528        2.22528
   0.958127       0.958127
  -0.211857      -0.211857
   0.354436       0.354436
   6.28299        6.28299
  -1.88306       -1.88306
   1.16816        1.16816
  -0.724852      -0.724852
   2.05035        2.05035
   1.1614         1.1614
  -0.0774035     -0.0774035
  -0.991458      -0.991458
  -2.224         -2.224
  -0.912683      -0.912683
  -2.33781       -2.33781
  -1.32562       -1.32562
   2.07222        2.07222
   1.86425        1.86425
  -1.12945       -1.12945
  -1.42154       -1.42154
  -1.83308       -1.83308
  -0.80144       -0.80144
   0.0659904      0.0659904
   0.46477        0.46477
   0.516478       0.516478
  -0.714539      -0.714539
   0.563923       0.563923
  -1.11843       -1.11843
   0.24327        0.24327
   1.9211         1.9211
   1.5536         1.5536
  -1.83635       -1.83635
   0.245734       0.245734
   0.894795       0.894795
   0.449533       0.449533
   1.83397        1.83397
   1.76346        1.76346
   3.16185        3.16185
   0.559932       0.559932
  -0.882377      -0.882377
  -0.717065      -0.717065
  -0.268154      -0.268154
   1.02418        1.02418
   2.46569        2.46569
  -0.737093      -0.737093
   0.872719       0.872719
   0.156786       0.156786
  -1.68971       -1.68971
  -0.762942      -0.762942
   0.0251112      0.0251112
   0.612489       0.612489
  -3.30371       -3.30371
  -0.698961      -0.698961
  -2.20203       -2.20203
  -1.89275       -1.89275
   0.0291887      0.0291887
  -0.61895       -0.61895
  -2.4545        -2.4545
   0.716685       0.716685
  -0.63556       -0.63556
   0.957159       0.957159
  -0.273225      -0.273225
  -0.441594      -0.441594
  -0.899482      -0.899482
  -2.85088       -2.85088
  -0.660739      -0.660739
   1.20197        1.20197
  -0.421759      -0.421759
   2.36317        2.36317
  -2.68519       -2.68519
   1.48605        1.48605
  -0.680547      -0.680547
  -3.61262       -3.61262
   0.200643       0.200643
   2.05747        2.05747
   2.03866        2.03866
  -1.53579       -1.53579
  -0.300568      -0.300568
   2.17815        2.17815
   0.889736       0.889736
  -0.269451      -0.269451
   3.85836        3.85836
  -0.0832182     -0.0832182
   0.575183       0.575183
  -0.90211       -0.90211
  -0.352595      -0.352595
   2.23507        2.23507
   0.863045       0.863045
   1.76841        1.76841
   0.159141       0.159141
  -0.187019      -0.187019
  -0.605252      -0.605252
   0.950606       0.950606
   0.126904       0.126904
  -1.33489       -1.33489
  -2.65456       -2.65456
   0.973579       0.973579
   1.11206        1.11206
   2.71157        2.71157
  -1.35922       -1.35922
  -2.09924       -2.09924
  -0.261339      -0.261339
  -0.71599       -0.71599
   0.957563       0.957563
  -2.38311       -2.38311
  -1.47771       -1.47771
   1.71136        1.71136
  -1.54574       -1.54574
  -0.66235       -0.66235
  -0.727048      -0.727048
   1.7508         1.7508
   3.09727        3.09727
   2.60078        2.60078
  -1.96873       -1.96873
   0.924622       0.924622
   0.287636       0.287636
   0.201588       0.201588
   0.638481       0.638481
   1.3465         1.3465
   1.56972        1.56972
   1.14971        1.14971
  -1.89176       -1.89176
   2.74371        2.74371
   1.23168        1.23168
   3.05252        3.05252
   0.608012       0.608012
  -1.21346       -1.21346
  -0.220215      -0.220215
   1.27374        1.27374
   1.89971        1.89971
  -0.315658      -0.315658
  -1.53046       -1.53046
  -0.815528      -0.815528
   1.11711        1.11711
  -1.86098       -1.86098
  -2.62764       -2.62764
  -1.94186       -1.94186
  -1.01812       -1.01812
   0.10927        0.10927
   1.83491        1.83491
   3.75411        3.75411
  -0.329943      -0.329943
   1.04999        1.04999
  -0.0572795     -0.0572795
  -1.19271       -1.19271
  -0.0640939     -0.0640939
   3.24013        3.24013
   1.19772        1.19772
   0.139843       0.139843
  -1.14619       -1.14619
  -0.346295      -0.346295
   0.314854       0.314854
  -1.86965       -1.86965
  -2.5997        -2.5997
   0.860876       0.860876
   0.779138       0.779138
  -1.48689       -1.48689
  -0.041387      -0.041387
   0.415675       0.415675
  -0.996154      -0.996154
  -0.210727      -0.210727
   3.01432        3.01432
  -0.818496      -0.818496
  -1.77229       -1.77229
  -5.1652        -5.1652
  -0.430049      -0.430049
   0.110492       0.110492
  -0.633977      -0.633977
   5.47398        5.47398
  -0.827223      -0.827223
   0.316164       0.316164
  -1.33416       -1.33416
  -2.58731       -2.58731
   0.331473       0.331473
  -0.495747      -0.495747
  -0.578983      -0.578983
   2.24558        2.24558
  -0.465562      -0.465562
  -0.88282       -0.88282
   1.00385        1.00385
  -0.986489      -0.986489
  -0.356386      -0.356386
   1.56415        1.56415
  -3.3696        -3.3696
  -2.39466       -2.39466
  -6.8684        -6.8684
  -0.705285      -0.705285
  -0.473808      -0.473808
   1.34126        1.34126
   1.17112        1.17112
  -0.638047      -0.638047
  -2.18021       -2.18021
  -0.748828      -0.748828
   1.33976        1.33976
   0.838517       0.838517
   0.229636       0.229636
  -1.10193       -1.10193
  -0.713668      -0.713668
   0.0447604      0.0447604
  -0.126929      -0.126929
  -2.65546       -2.65546
  -0.407056      -0.407056
  -0.224281      -0.224281
  -0.206263      -0.206263
   1.59537        1.59537
   2.12341        2.12341
  -0.165041      -0.165041
   0.745372       0.745372
  -2.61492       -2.61492
   0.764695       0.764695
  -0.721477      -0.721477
   2.71105        2.71105
   0.400047       0.400047
  -0.620564      -0.620564
  -0.676275      -0.676275
  -1.65892       -1.65892
   0.153766       0.153766
  -0.789512      -0.789512
   0.718952       0.718952
  -1.3161        -1.3161
   1.3924         1.3924
  -0.752873      -0.752873
   1.47481        1.47481
   0.764075       0.764075
   1.13314        1.13314
   1.11338        1.11338
   0.0911534      0.0911534
   0.358637       0.358637
   0.443527       0.443527
  -1.65442       -1.65442
  -1.18768       -1.18768
  -0.671452      -0.671452
  -0.10452       -0.10452
   2.63571        2.63571
  -0.365343      -0.365343
   0.989189       0.989189
   1.016          1.016
   0.02238        0.02238
   2.5152         2.5152
  -0.502349      -0.502349
   2.07812        2.07812
  -2.60912       -2.60912
   0.039301       0.039301
   2.21963        2.21963
  -1.25433       -1.25433
   1.04089        1.04089
   2.15635        2.15635
  -1.17901       -1.17901
   0.464251       0.464251
   0.523713       0.523713
   2.6929         2.6929
  -3.17565       -3.17565
  -0.0704547     -0.0704547
   0.316088       0.316088
  -0.595716      -0.595716
  -0.962247      -0.962247
   2.07635        2.07635
  -0.707047      -0.707047
  -1.95768       -1.95768
  -1.05889       -1.05889
  -0.346038      -0.346038
  -0.519161      -0.519161
   0.679303       0.679303
   0.668559       0.668559
  -1.18768       -1.18768
   1.05391        1.05391
   0.495406       0.495406
   0.775206       0.775206
   1.21855        1.21855
  -0.188646      -0.188646
   2.78981        2.78981
   0.276702       0.276702
  -2.51357       -2.51357
   0.893815       0.893815
  -0.600099      -0.600099
   1.27468        1.27468
   0.176813       0.176813
  -0.97769       -0.97769
  -0.831947      -0.831947
  -0.78568       -0.78568
   1.54688        1.54688
  -1.66614       -1.66614
   1.74662        1.74662
  -0.144336      -0.144336
   3.25977        3.25977
   0.604924       0.604924
  -1.08699       -1.08699
   0.337396       0.337396
   0.6638         0.6638
  -1.03335       -1.03335
  -2.12209       -2.12209
  -4.10625       -4.10625
   0.575479       0.575479
  -0.703679      -0.703679
   0.455751       0.455751
  -3.87142       -3.87142
   1.82789        1.82789
  -1.17806       -1.17806
  -0.555556      -0.555556
  -3.14948       -3.14948
   2.48156        2.48156
   1.53411        1.53411
  -0.306063      -0.306063
   0.182748       0.182748
  -4.68966       -4.68966
   1.65411        1.65411
  -0.471352      -0.471352
   2.08115        2.08115
  -1.14689       -1.14689
   1.7511         1.7511
   2.02855        2.02855
  -0.842776      -0.842776
   0.708793       0.708793
  -0.663495      -0.663495
   0.752657       0.752657
  -0.837532      -0.837532
   1.94326        1.94326
  -1.0195        -1.0195
  -0.189062      -0.189062
   0.443252       0.443252
   1.53346        1.53346
  -1.06344       -1.06344
   2.09193        2.09193
   1.11391        1.11391
   0.973692       0.973692
   1.60649        1.60649
  -2.98173       -2.98173
  -1.30708       -1.30708
   0.686241       0.686241
   1.44115        1.44115
  -0.804022      -0.804022
   0.128653       0.128653
   0.148315       0.148315
   1.05242        1.05242
   4.81345        4.81345
  -0.0360308     -0.0360308
  -0.0977653     -0.0977653
   2.50497        2.50497
   0.0427317      0.0427317
   1.07616        1.07616
   2.6184         2.6184
   4.16012        4.16012
   1.94137        1.94137
   0.168671       0.168671
   0.249589       0.249589
   2.29888        2.29888
  -2.58131       -2.58131
   1.02287        1.02287
  -3.24177       -3.24177
   0.0501678      0.0501678
  -3.08706       -3.08706
  -1.81322       -1.81322
  -3.21173       -3.21173
  -0.605546      -0.605546
   1.80962        1.80962
   1.1928         1.1928
   1.16219        1.16219
  -0.502315      -0.502315
  -2.12962       -2.12962
   1.82909        1.82909
  -0.515471      -0.515471
   0.465682       0.465682
  -2.27668       -2.27668
  -0.794018      -0.794018
   0.906492       0.906492
  -2.97682       -2.97682
   1.76548        1.76548
  -2.14784       -2.14784
  -1.70079       -1.70079
   0.575641       0.575641
   2.18061        2.18061
   0.721652       0.721652
   3.34416        3.34416
   2.92373        2.92373
  -2.27608       -2.27608
  -0.147619      -0.147619
   2.27896        2.27896
   3.13783        3.13783
   0.53847        0.53847
   1.59368        1.59368
  -2.92919       -2.92919
  -0.665617      -0.665617
   2.21631        2.21631
  -0.132953      -0.132953
   0.255364       0.255364
   1.26044        1.26044
  -0.234991      -0.234991
   0.0326571      0.0326571
   1.95529        1.95529
  -0.147709      -0.147709
   0.837403       0.837403
   0.264494       0.264494
  -0.79803       -0.79803
   1.24209        1.24209
   4.16292        4.16292
   2.90203        2.90203
  -1.77443       -1.77443
  -1.25963       -1.25963
  -1.97697       -1.97697
  -0.0228958     -0.0228958
   0.961171       0.961171
  -1.98808       -1.98808
   1.9206         1.9206
   0.948345       0.948345
  -0.26941       -0.26941
  -0.895958      -0.895958
  -0.0969616     -0.0969616
  -1.8459        -1.8459
   1.06631        1.06631
   0.582305       0.582305
   0.949072       0.949072
  -1.12433       -1.12433
   1.75585        1.75585
  -4.27514       -4.27514
   0.193812       0.193812
  -0.879839      -0.879839
   0.740636       0.740636
  -1.46844       -1.46844
   1.1903         1.1903
   0.14461        0.14461
  -2.83538       -2.83538
   1.90454        1.90454
  -1.91853       -1.91853
  -0.606642      -0.606642
   2.28632        2.28632
   1.92542        1.92542
   2.53635        2.53635
   1.55833        1.55833
   1.52359        1.52359
   0.777676       0.777676
   3.06456        3.06456
   0.288197       0.288197
   1.2306         1.2306
  -1.57984       -1.57984
  -2.09081       -2.09081
   2.21411        2.21411
  -0.0590976     -0.0590976
   0.0967886      0.0967886
   1.56966        1.56966
   1.0458         1.0458
   2.13399        2.13399
   0.582962       0.582962
  -3.258         -3.258
   1.31176        1.31176
   2.12008        2.12008
   0.420016       0.420016
   1.16769        1.16769
   0.322813       0.322813
  -2.08123       -2.08123
  -0.366867      -0.366867
  -0.863194      -0.863194
   2.1781         2.1781
  -0.607621      -0.607621
  -1.46271       -1.46271
  -0.645887      -0.645887
   2.07943        2.07943
   1.66221        1.66221
   1.00057        1.00057
   1.96566        1.96566
   1.40844        1.40844
   1.99744        1.99744
  -1.17224       -1.17224
   0.688052       0.688052
  -1.56755       -1.56755
  -1.1927        -1.1927
   1.44395        1.44395
   0.739251       0.739251
   2.06788        2.06788
   0.603058       0.603058
  -0.749518      -0.749518
   0.935585       0.935585
  -0.671683      -0.671683
  -0.489752      -0.489752
   0.984702       0.984702
   0.571385       0.571385
  -0.386589      -0.386589
   1.61408        1.61408
   2.16478        2.16478
   2.3196         2.3196
  -2.31076       -2.31076
  -0.186898      -0.186898
   1.61571        1.61571
  -0.369523      -0.369523
  -2.21236       -2.21236
  -3.84185       -3.84185
  -0.0851651     -0.0851651
   0.295692       0.295692
  -2.87568       -2.87568
   2.97524        2.97524
   0.974503       0.974503
   2.36206        2.36206
  -1.7699        -1.7699
   1.04331        1.04331
  -1.8445        -1.8445
  -1.58605       -1.58605
  -0.410044      -0.410044
  -0.588594      -0.588594
  -0.916676      -0.916676
   0.493802       0.493802
   0.0781382      0.0781382
  -0.958667      -0.958667
   0.237942       0.237942
   0.344577       0.344577
  -0.155517      -0.155517
  -0.0599809     -0.0599809
   0.625756       0.625756
   1.083          1.083
  -1.55908       -1.55908
  -0.0447221     -0.0447221
   2.29293        2.29293
  -0.818719      -0.818719
  -0.431673      -0.431673
   0.807989       0.807989
  -1.49538       -1.49538
  -0.415386      -0.415386
  -0.368204      -0.368204
   0.822768       0.822768
  -1.04757       -1.04757
   1.50985        1.50985
   0.591814       0.591814
   0.576176       0.576176
   2.2397         2.2397
  -2.87292       -2.87292
  -1.05271       -1.05271
  -0.584545      -0.584545
  23.6334        23.6334
  -1.94422       -1.94422
  -2.4793        -2.4793
  -0.461402      -0.461402
  -2.68547       -2.68547
   1.27863        1.27863
   0.349233       0.349233
  -1.58019       -1.58019
   1.55179        1.55179
  -0.206459      -0.206459
  -0.985779      -0.985779
   0.943214       0.943214
  -0.110792      -0.110792
  -0.0489029     -0.0489029
   2.33366        2.33366
  -1.6701        -1.6701
   0.201543       0.201543
  -0.0789827     -0.0789827
  -1.27944       -1.27944
  -1.77649       -1.77649
   0.872661       0.872661
   2.52858        2.52858
   2.94238        2.94238
   1.27241        1.27241
  -0.58158       -0.58158
   1.37193        1.37193
   2.03604        2.03604
   2.76534        2.76534
   1.36309        1.36309
   0.910546       0.910546
   1.2274         1.2274
   0.501399       0.501399
   1.69964        1.69964
  -0.0684446     -0.0684446
  -0.271516      -0.271516
  -2.72402       -2.72402
  -0.962159      -0.962159
  -0.396473      -0.396473
   0.924897       0.924897
  -1.1069        -1.1069
   2.62532        2.62532
  -0.393446      -0.393446
  -0.136789      -0.136789
  -0.151452      -0.151452
  -0.096789      -0.096789
   2.1524         2.1524
   1.68668        1.68668
  -0.730035      -0.730035
   1.92158        1.92158
  -3.87326       -3.87326
  -0.221315      -0.221315
  -0.355481      -0.355481
  -0.775173      -0.775173
   1.7409         1.7409
   1.3288         1.3288
 -12.0217       -12.0217
   0.583705       0.583705
   0.184282       0.184282
   0.417036       0.417036
  -0.956676      -0.956676
   0.520674       0.520674
  -0.899164      -0.899164
   3.50664        3.50664
  -0.636307      -0.636307
  -1.73476       -1.73476
   1.29043        1.29043
   0.472702       0.472702
  -1.79694       -1.79694
  -1.04534       -1.04534
   1.10865        1.10865
  -1.43563       -1.43563
  -1.20749       -1.20749
   1.26766        1.26766
   0.673491       0.673491
  -0.934399      -0.934399
   2.26572        2.26572
  -1.46043       -1.46043
   2.209          2.209
  -1.00799       -1.00799
  -0.148943      -0.148943
  -1.1825        -1.1825
  -1.21252       -1.21252
   0.282581       0.282581
   0.41457        0.41457
   2.20195        2.20195
   0.0617071      0.0617071
  -0.550251      -0.550251
  -1.06407       -1.06407
   0.642124       0.642124
  -2.1808        -2.1808
   0.495721       0.495721
   0.932684       0.932684
   2.11964        2.11964
   2.48226        2.48226
   1.99288        1.99288
  -0.40534       -0.40534
  -0.830009      -0.830009
   0.694545       0.694545
  -1.87861       -1.87861
   0.656508       0.656508
   1.45896        1.45896
   0.831577       0.831577
   1.56499        1.56499
   0.220691       0.220691
  -1.53346       -1.53346
   2.11808        2.11808
  -0.172959      -0.172959
   2.30349        2.30349
  -0.415921      -0.415921
  -0.412111      -0.412111
  -1.08472       -1.08472
   0.878408       0.878408
  -1.59121       -1.59121
   1.27521        1.27521
   1.49535        1.49535
   1.01611        1.01611
   0.826557       0.826557
   0.413962       0.413962
  -0.418091      -0.418091
  -1.27713       -1.27713
  -1.72911       -1.72911
  -0.680069      -0.680069
  -3.18506       -3.18506
   0.144236       0.144236
  -1.3908        -1.3908
  -1.37211       -1.37211
  -0.583177      -0.583177
  -2.50307       -2.50307
   0.214101       0.214101
  -0.742307      -0.742307
   0.806269       0.806269
  -0.58649       -0.58649
  -1.13406       -1.13406
   0.589182       0.589182
  -1.41751       -1.41751
   0.38813        0.38813
  -0.761625      -0.761625
  -1.82823       -1.82823
  -2.76721       -2.76721
  -0.555275      -0.555275
   2.20053        2.20053
   0.989203       0.989203
  -1.94756       -1.94756
  -3.27283       -3.27283
   1.82038        1.82038
   1.73285        1.73285
  -3.36146       -3.36146
  -0.0434622     -0.0434622
  -3.1662        -3.1662
  -2.27172       -2.27172
  -1.64158       -1.64158
   1.36217        1.36217
   0.0614365      0.0614365
  -1.51214       -1.51214
   0.525372       0.525372
  -2.38711       -2.38711
   0.91023        0.91023
   0.642573       0.642573
   0.787917       0.787917
  -0.165626      -0.165626
  -2.5386        -2.5386
  -0.0847667     -0.0847667
  -1.73854       -1.73854
  -0.629933      -0.629933
   0.0476356      0.0476356
  -2.96352       -2.96352
   2.43105        2.43105
   3.07803        3.07803
   1.61165        1.61165
   1.80835        1.80835
   2.6522         2.6522
   2.42881        2.42881
   1.95263        1.95263
  -0.627659      -0.627659
  -2.94554       -2.94554
  -0.584281      -0.584281
   0.174889       0.174889
   1.63772        1.63772
  -2.90996       -2.90996
  -1.19518       -1.19518
  -0.30899       -0.30899
  -1.44569       -1.44569
   0.380009       0.380009
  -1.09017       -1.09017
   0.401782       0.401782
  -1.01077       -1.01077
  -0.391996      -0.391996
  -0.284267      -0.284267
  -0.281839      -0.281839
   0.0555518      0.0555518
   1.16644        1.16644
  -2.17393       -2.17393
  -3.02707       -3.02707
  -0.744337      -0.744337
   0.614164       0.614164
  -1.26162       -1.26162
  -0.892012      -0.892012
  -1.38321       -1.38321
  -0.690443      -0.690443
  -0.190017      -0.190017
   0.652475       0.652475
  -0.665589      -0.665589
  -0.958746      -0.958746
   0.211427       0.211427
   0.172027       0.172027
  -0.183977      -0.183977
  -4.92239       -4.92239
   0.234765       0.234765
  -0.128532      -0.128532
  -0.397255      -0.397255
   0.637882       0.637882
  -0.665182      -0.665182
   0.989375       0.989375
  13.9866        13.9866
   0.507452       0.507452
   1.82993        1.82993
  -0.661663      -0.661663
  -0.315201      -0.315201
   0.0298377      0.0298377
  -1.02559       -1.02559
   1.67329        1.67329
   0.770169       0.770169
  -0.567072      -0.567072
  -0.822084      -0.822084
  -0.695256      -0.695256
  -0.81899       -0.81899
   0.00983914     0.00983914
   3.47498        3.47498
  -0.0516518     -0.0516518
   1.07953        1.07953
  -0.286307      -0.286307
  -0.901457      -0.901457
   0.111325       0.111325
   0.724452       0.724452
  -0.672886      -0.672886
   0.821217       0.821217
  -3.77372       -3.77372
   0.461435       0.461435
  -0.231648      -0.231648
   1.41987        1.41987
   1.03119        1.03119
   0.93142        0.93142
  -0.913693      -0.913693
   2.17759        2.17759
   1.63487        1.63487
  -0.0814173     -0.0814173
  -1.10167       -1.10167
   0.479772       0.479772
   0.542071       0.542071
   0.226907       0.226907
   0.484866       0.484866
  -2.79594       -2.79594
   1.17344        1.17344
   0.448936       0.448936
  -0.425432      -0.425432
  -0.816027      -0.816027
   1.11008        1.11008
   2.16526        2.16526
   0.574023       0.574023
   3.34678        3.34678
   3.05037        3.05037
  -1.49271       -1.49271
  -1.14698       -1.14698
   0.556459       0.556459
  -1.01214       -1.01214
  -0.309133      -0.309133
  -0.536957      -0.536957
   1.62871        1.62871
  -2.88469       -2.88469
  -0.0979174     -0.0979174
  -3.37567       -3.37567
   2.46043        2.46043
  -0.730684      -0.730684
  -0.900807      -0.900807
  -2.45852       -2.45852
  -0.108725      -0.108725
  -1.01572       -1.01572
  -3.68841       -3.68841
   0.290852       0.290852
   1.68984        1.68984
   3.35964        3.35964
  -1.31673       -1.31673
   0.321869       0.321869
   2.34154        2.34154
  -1.67666       -1.67666
  -0.035619      -0.035619
  -2.13567       -2.13567
   1.3469         1.3469
   0.153865       0.153865
   1.14801        1.14801
  -0.713299      -0.713299
  -0.412727      -0.412727
  -1.01501       -1.01501
  -0.578133      -0.578133
   0.684314       0.684314
   3.48687        3.48687
   1.21238        1.21238
  -1.95149       -1.95149
  -3.36448       -3.36448
  -0.819665      -0.819665
   0.277849       0.277849
   1.29952        1.29952
  -0.717767      -0.717767
  -0.0224495     -0.0224495
  -0.95711       -0.95711
  -2.57496       -2.57496
   0.856373       0.856373
   0.938171       0.938171
  -0.492205      -0.492205
  -1.45455       -1.45455
   1.95963        1.95963
  -0.169591      -0.169591
   1.93841        1.93841
  -0.0293303     -0.0293303
  -1.06165       -1.06165
   0.0963018      0.0963018
  -0.0253168     -0.0253168
  -0.615891      -0.615891
  -1.84572       -1.84572
   2.04114        2.04114
   0.709038       0.709038
 -11.8503       -11.8503
   1.30469        1.30469
   1.29953        1.29953
  -0.0864412     -0.0864412
  -2.55483       -2.55483
   0.0868521      0.0868521
  -0.472505      -0.472505
  -2.22982       -2.22982
   0.675526       0.675526
   0.903289       0.903289
   2.1813         2.1813
  -0.731082      -0.731082
   1.23144        1.23144
   0.211691       0.211691
  -0.447575      -0.447575
  -0.266834      -0.266834
   0.777422       0.777422
   2.13011        2.13011
   1.14053        1.14053
  -1.64879       -1.64879
   0.253671       0.253671
   1.37881        1.37881
  -3.47648       -3.47648
   0.120876       0.120876
   0.706163       0.706163
  -0.408708      -0.408708
   1.63921        1.63921
  -0.0897068     -0.0897068
  -0.36319       -0.36319
  -2.72738       -2.72738
   0.778532       0.778532
  -1.44104       -1.44104
  -0.477193      -0.477193
   2.99272        2.99272
  -1.93478       -1.93478
   0.7366         0.7366
  -0.461307      -0.461307
   1.34756        1.34756
   0.575798       0.575798
   0.243039       0.243039
   0.00184323     0.00184323
  -4.65195       -4.65195
  -0.0233881     -0.0233881
   2.27189        2.27189
  -0.454542      -0.454542
  -0.621287      -0.621287
  -1.95901       -1.95901
  -1.59841       -1.59841
  -1.11109       -1.11109
   0.276918       0.276918
   0.822635       0.822635
   0.399364       0.399364
  -3.59          -3.59
   0.63147        0.63147
  -0.122051      -0.122051
  -2.99397       -2.99397
  -0.199531      -0.199531
   1.70567        1.70567
  -0.802968      -0.802968
   1.54216        1.54216
   5.01761        5.01761
   0.593876       0.593876
   1.4851         1.4851
  -0.16419       -0.16419
  -2.67396       -2.67396
  -1.4692        -1.4692
   3.53628        3.53628
   0.842369       0.842369
  -1.10273       -1.10273
   1.38417        1.38417
  -0.654059      -0.654059
   3.03409        3.03409
  -0.599392      -0.599392
  -2.90447       -2.90447
  -1.42843       -1.42843
   1.0605         1.0605
   0.648235       0.648235
  -1.72383       -1.72383
  -0.356193      -0.356193
  -0.538367      -0.538367
  -3.79779       -3.79779
   3.63493        3.63493
  -0.464008      -0.464008
   0.347418       0.347418
  -0.467898      -0.467898
   0.672538       0.672538
  -0.160574      -0.160574
  -3.60299       -3.60299
   2.72608        2.72608
   0.337715       0.337715
  -0.859081      -0.859081
   4.38695        4.38695
   2.18067        2.18067
  -1.61338       -1.61338
  -0.448975      -0.448975
  -1.84397       -1.84397
   0.0152013      0.0152013
   0.667211       0.667211
  -0.0943334     -0.0943334
   0.860503       0.860503
  -0.115682      -0.115682
  -0.284645      -0.284645
   3.97725        3.97725
   1.98285        1.98285
   0.576249       0.576249
  -1.60365       -1.60365
   6.83394        6.83394
   3.17895        3.17895
   2.29932        2.29932
   0.077594       0.077594
  -0.862484      -0.862484
  -0.455567      -0.455567
   1.0918         1.0918
  -1.05352       -1.05352
  -0.503157      -0.503157
  -1.28519       -1.28519
  -2.55219       -2.55219
  -0.511736      -0.511736
  -0.601855      -0.601855
   1.38829        1.38829
   1.72822        1.72822
   2.44367        2.44367
  -0.876967      -0.876967
   1.32143        1.32143
  -0.345428      -0.345428
   0.158257       0.158257
  -0.502065      -0.502065
   0.602091       0.602091
   0.546799       0.546799
   0.144201       0.144201
   1.28249        1.28249
  -0.766982      -0.766982
  -2.91678       -2.91678
  -0.420817      -0.420817
   0.282388       0.282388
  -2.35922       -2.35922
  -0.959736      -0.959736
   0.970576       0.970576
   1.28214        1.28214
  -1.38422       -1.38422
  -1.28912       -1.28912
  -1.55508       -1.55508
   2.60786        2.60786
  -0.174129      -0.174129
  -4.97013       -4.97013
  -3.13894       -3.13894
  -1.0113        -1.0113
   0.29012        0.29012
   0.301534       0.301534
  -1.36587       -1.36587
   0.592223       0.592223
  -0.393313      -0.393313
   1.54523        1.54523
   0.489536       0.489536
   0.431823       0.431823
  -0.698724      -0.698724
   0.597885       0.597885
  -1.28348       -1.28348
   9.20118        9.20118
   0.523845       0.523845
   1.64891        1.64891
   1.26397        1.26397
  -0.0614047     -0.0614047
   0.0327276      0.0327276
  -0.4776        -0.4776
  -2.24761       -2.24761
   1.49423        1.49423
  -1.70954       -1.70954
  -0.174842      -0.174842
   0.35175        0.35175
   0.549776       0.549776
  -1.97708       -1.97708
  -0.797726      -0.797726
  -0.880683      -0.880683
   1.92272        1.92272
  -1.05489       -1.05489
  -2.33809       -2.33809
  -1.59936       -1.59936
  -0.840616      -0.840616
   2.6777         2.6777
   0.86962        0.86962
  -1.01078       -1.01078
  -0.936281      -0.936281
  -1.24079       -1.24079
  -2.68717       -2.68717
   0.22939        0.22939
   0.75135        0.75135
   1.07189        1.07189
  -0.0904491     -0.0904491
  -2.72094       -2.72094
   0.259405       0.259405
   0.801323       0.801323
   1.79821        1.79821
   0.13453        0.13453
  -0.294662      -0.294662
   1.39746        1.39746
  -0.876874      -0.876874
   0.411162       0.411162
  -1.2239        -1.2239
  -0.85717       -0.85717
   0.50512        0.50512
   1.59327        1.59327
  -1.76924       -1.76924
   2.85557        2.85557
  -2.69548       -2.69548
  -1.5875        -1.5875
  -0.796946      -0.796946
  -0.335648      -0.335648
  -0.512417      -0.512417
   2.13108        2.13108
  -1.85765       -1.85765
  -2.89643       -2.89643
   1.76352        1.76352
   0.575773       0.575773
   1.59789        1.59789
   1.42267        1.42267
   0.497862       0.497862
  -0.567461      -0.567461
   1.36287        1.36287
   2.10155        2.10155
  -1.18077       -1.18077
   2.49273        2.49273
  -1.94928       -1.94928
   0.324793       0.324793
   0.140937       0.140937
   2.33415        2.33415
  -0.0985955     -0.0985955
   1.71064        1.71064
  -0.274678      -0.274678
   0.82142        0.82142
   1.97483        1.97483
   1.33147        1.33147
   1.25382        1.25382
  -1.92684       -1.92684
   0.633816       0.633816
  -1.74887       -1.74887
  -0.935251      -0.935251
   0.406894       0.406894
   0.630239       0.630239
   1.49081        1.49081
  -1.7665        -1.7665
   0.468253       0.468253
  -0.829623      -0.829623
   0.683713       0.683713
   0.343987       0.343987
   1.87329        1.87329
  -0.46613       -0.46613
   2.83798        2.83798
   1.64433        1.64433
   0.303556       0.303556
  -0.810505      -0.810505
  -0.548167      -0.548167
   1.77963        1.77963
   0.0793537      0.0793537
  -3.29027       -3.29027
  -0.183904      -0.183904
  -1.61751       -1.61751
   0.860805       0.860805
  -0.722543      -0.722543
   0.0263393      0.0263393
  -1.53128       -1.53128
  -0.242737      -0.242737
   0.319961       0.319961
   2.17752        2.17752
   0.845624       0.845624
   1.91994        1.91994
   0.258224       0.258224
   0.256254       0.256254
  -0.64679       -0.64679
   1.51706        1.51706
   1.2567         1.2567
  -0.0595054     -0.0595054
   3.78386        3.78386
   0.0964969      0.0964969
   0.822442       0.822442
   2.36122        2.36122
   1.19663        1.19663
   1.45557        1.45557
  -0.487415      -0.487415
   2.80363        2.80363
   0.354397       0.354397
   2.064          2.064
  -1.60732       -1.60732
   0.152285       0.152285
  -1.06767       -1.06767
  -2.89226       -2.89226
  -0.923556      -0.923556
   0.129633       0.129633
   0.414714       0.414714
   0.313557       0.313557
  -0.63598       -0.63598
  -1.24145       -1.24145
   0.445823       0.445823
  -1.18621       -1.18621
  -0.824399      -0.824399
   0.0348621      0.0348621
   1.72359        1.72359
   3.23846        3.23846
  -0.982701      -0.982701
  -2.8631        -2.8631
  -0.247987      -0.247987
   1.10508        1.10508
  -0.335101      -0.335101
   1.59819        1.59819
   0.363252       0.363252
  -1.22112       -1.22112
   2.40608        2.40608
   2.14135        2.14135
   0.926073       0.926073
  -0.616568      -0.616568
   0.829974       0.829974
   4.0788         4.0788
   1.97497        1.97497
  -0.943884      -0.943884
   0.770483       0.770483
   1.58248        1.58248
   2.10963        2.10963
  -3.33186       -3.33186
   1.52246        1.52246
  -1.38448       -1.38448
   0.178628       0.178628
   2.35971        2.35971
   1.35345        1.35345
   2.2217         2.2217
  -1.6579        -1.6579
   0.752211       0.752211
   1.60611        1.60611
   0.224136       0.224136
   0.8147         0.8147
  -6.54244       -6.54244
   2.03158        2.03158
   0.334614       0.334614
  -0.849204      -0.849204
   0.573662       0.573662
   0.834273       0.834273
   1.98059        1.98059
   4.59366        4.59366
  -0.0696824     -0.0696824
  -1.12577       -1.12577
  -0.392295      -0.392295
   0.608493       0.608493
   1.57322        1.57322
   0.724246       0.724246
  -2.54194       -2.54194
  -0.61659       -0.61659
   1.52939        1.52939
   0.628167       0.628167
   0.153008       0.153008
   0.729473       0.729473
   1.80753        1.80753
  -0.257529      -0.257529
   2.30209        2.30209
  -1.07183       -1.07183
  -2.34549       -2.34549
   1.7575         1.7575
  -1.09788       -1.09788
  -0.733157      -0.733157
  -1.15178       -1.15178
  -1.38334       -1.38334
  -0.282802      -0.282802
  -1.64302       -1.64302
  -8.14652       -8.14652
   0.230736       0.230736
   1.49834        1.49834
  -3.92113       -3.92113
   1.26241        1.26241
  -0.867555      -0.867555
   0.385275       0.385275
  -1.52048       -1.52048
  -3.58632       -3.58632
   0.216633       0.216633
  -0.626523      -0.626523
   0.0498179      0.0498179
  -0.736738      -0.736738
  -1.96551       -1.96551
  -0.886975      -0.886975
  -4.19118       -4.19118
   4.69049        4.69049
   1.24464        1.24464
   0.559333       0.559333
   0.365196       0.365196
   2.05931        2.05931
  -1.61866       -1.61866
  -0.937082      -0.937082
  -2.28156       -2.28156
   0.480478       0.480478
   0.0375252      0.0375252
   1.16423        1.16423
   1.06467        1.06467
  -1.51476       -1.51476
   0.639421       0.639421
   0.835906       0.835906
   0.0678173      0.0678173
   0.911222       0.911222
   0.178712       0.178712
   0.16706        0.16706
  -0.338281      -0.338281
   1.13458        1.13458
   2.369          2.369
   0.104902       0.104902
   3.74878        3.74878
  -0.66965       -0.66965
  -0.539803      -0.539803
   8.81148        8.81148
   2.01163        2.01163
  -2.44142       -2.44142
   1.71428        1.71428
   0.195195       0.195195
   0.886484       0.886484
  -1.61999       -1.61999
   1.38916        1.38916
  -0.182804      -0.182804
  -2.12762       -2.12762
   1.32879        1.32879
   2.93628        2.93628
   0.585458       0.585458
   0.759949       0.759949
   0.200884       0.200884
   0.434392       0.434392
   0.592809       0.592809
  -0.972697      -0.972697
  -0.30606       -0.30606
   2.75682        2.75682
   1.06405        1.06405
   0.535445       0.535445
   0.245727       0.245727
  -0.881514      -0.881514
  -0.90398       -0.90398
   1.34242        1.34242
   0.974607       0.974607
  -0.23557       -0.23557
  -2.36657       -2.36657
   2.20975        2.20975
   0.372629       0.372629
  -0.7674        -0.7674
   0.503398       0.503398
  -0.39968       -0.39968
   4.73687        4.73687
   1.83971        1.83971
  -0.59006       -0.59006
  -3.12939       -3.12939
   1.67781        1.67781
  -0.346719      -0.346719
  -1.20046       -1.20046
  -0.543011      -0.543011
   2.00497        2.00497
  -2.29529       -2.29529
   1.46115        1.46115
  -1.93647       -1.93647
   0.346798       0.346798
  -0.781626      -0.781626
  -3.73517       -3.73517
   0.403249       0.403249
   0.147234       0.147234
   0.581328       0.581328
  -1.56541       -1.56541
  -0.0382613     -0.0382613
  -2.69999       -2.69999
   2.53761        2.53761
   0.485891       0.485891
   2.04661        2.04661
  -1.34907       -1.34907
  -2.77599       -2.77599
  -1.9941        -1.9941
   2.26706        2.26706
  -0.841907      -0.841907
   2.89779        2.89779
   1.34194        1.34194
   1.72031        1.72031
   0.35742        0.35742
  -0.673142      -0.673142
  -1.97963       -1.97963
   2.99822        2.99822
   0.84135        0.84135
   0.467833       0.467833
  -1.6184        -1.6184
   0.545393       0.545393
   0.0865121      0.0865121
   1.38347        1.38347
   2.3421         2.3421
   2.6215         2.6215
  -1.48313       -1.48313
   2.29728        2.29728
  -0.629032      -0.629032
  -0.053791      -0.053791
   0.827546       0.827546
  -2.01859       -2.01859
  -0.151077      -0.151077
  -4.74001       -4.74001
  -2.07772       -2.07772
   0.964427       0.964427
   1.76579        1.76579
  -2.11515       -2.11515
   2.99605        2.99605
   1.38556        1.38556
  -2.60586       -2.60586
  -3.05364       -3.05364
  -1.22284       -1.22284
   0.499165       0.499165
   1.22502        1.22502
  -0.887611      -0.887611
   1.1518         1.1518
  -2.7606        -2.7606
   0.106263       0.106263
   0.92196        0.92196
  -0.542352      -0.542352
   0.772226       0.772226
  -0.409383      -0.409383
  -0.480159      -0.480159
   0.434618       0.434618
  -1.93489       -1.93489
   1.0037         1.0037
   0.760285       0.760285
   0.380404       0.380404
   2.45566        2.45566
  -1.03099       -1.03099
   0.652107       0.652107
  -1.64881       -1.64881
  -1.38051       -1.38051
   1.43146        1.43146
  -0.366772      -0.366772
   1.06121        1.06121
   0.20026        0.20026
   0.646821       0.646821
   0.361296       0.361296
   0.547448       0.547448
   1.46293        1.46293
   1.10425        1.10425
  -1.98927       -1.98927
   1.33293        1.33293
   0.702344       0.702344
  -0.294478      -0.294478
   2.57426        2.57426
   0.972237       0.972237
  -1.8532        -1.8532
  -1.52489       -1.52489
  -1.92059       -1.92059
   0.4566         0.4566
   0.0146066      0.0146066
   1.15567        1.15567
  -2.15427       -2.15427
  -0.896258      -0.896258
  -0.579245      -0.579245
   4.10418        4.10418
   0.147275       0.147275
  -2.60135       -2.60135
   1.13637        1.13637
   4.39171        4.39171
  -3.93541       -3.93541
  -2.25406       -2.25406
  -0.766558      -0.766558
   1.32684        1.32684
   0.701722       0.701722
   1.07565        1.07565
  -0.881368      -0.881368
  -1.79475       -1.79475
  -0.12303       -0.12303
   0.939797       0.939797
  -1.63244       -1.63244
  -0.561795      -0.561795
   0.668111       0.668111
   2.28615        2.28615
   1.6027         1.6027
   0.210892       0.210892
   1.10496        1.10496
  -3.5233        -3.5233
   0.315028       0.315028
  -2.40724       -2.40724
  -0.865286      -0.865286
  -0.178629      -0.178629
   4.42947        4.42947
   2.0842         2.0842
  -1.17052       -1.17052
  -0.573684      -0.573684
  -0.230861      -0.230861
  -0.00536986    -0.00536986
   1.18437        1.18437
   0.954435       0.954435
   0.475723       0.475723
  -1.45097       -1.45097
  -0.946094      -0.946094
  -0.371655      -0.371655
  -1.73344       -1.73344
   0.25137        0.25137
  -0.904498      -0.904498
   1.72233        1.72233
  -0.0630691     -0.0630691
   1.20918        1.20918
  -1.58876       -1.58876
  -3.08633       -3.08633
   0.469343       0.469343
   0.334824       0.334824
  -0.420134      -0.420134
  -1.39986       -1.39986
  -0.65878       -0.65878
  -0.680645      -0.680645
  -1.46235       -1.46235
  -1.7763        -1.7763
   0.061792       0.061792
   2.10605        2.10605
  -0.198492      -0.198492
   0.437371       0.437371
  -1.539         -1.539
  -0.615466      -0.615466
   0.739653       0.739653
  -1.62828       -1.62828
  -3.99554       -3.99554
  -0.0523548     -0.0523548
   1.77712        1.77712
  -0.756514      -0.756514
   1.43585        1.43585
  -0.730324      -0.730324
  -0.714939      -0.714939
  -0.208195      -0.208195
   3.00343        3.00343
  -0.780319      -0.780319
  -1.67158       -1.67158
  -4.72578       -4.72578
  -0.409396      -0.409396
  -0.182756      -0.182756
   0.131891       0.131891
  -0.0622689     -0.0622689
   0.504642       0.504642
   1.05712        1.05712
   0.603898       0.603898
  -1.08295       -1.08295
   3.50826        3.50826
  -1.21709       -1.21709
   2.62074        2.62074
   2.27406        2.27406
  -0.444599      -0.444599
  -1.23079       -1.23079
   2.01351        2.01351
  -0.771506      -0.771506
  -1.25143       -1.25143
  -2.42808       -2.42808
   0.618042       0.618042
  -0.139276      -0.139276
  -1.15122       -1.15122
  -1.00705       -1.00705
  -0.513695      -0.513695
   1.49666        1.49666
   2.08012        2.08012
  -0.0331592     -0.0331592
  -1.27368       -1.27368
   0.237436       0.237436
  -1.92915       -1.92915
  -3.38558       -3.38558
   0.656076       0.656076
   4.89326        4.89326
  -0.696932      -0.696932
   1.81671        1.81671
  -0.163389      -0.163389
  -0.640608      -0.640608
  -0.466348      -0.466348
   0.790762       0.790762
  -0.15507       -0.15507
  -0.387485      -0.387485
   3.22853        3.22853
  -0.361262      -0.361262
   0.838794       0.838794
  -1.80534       -1.80534
  -0.514814      -0.514814
  -1.96885       -1.96885
  -1.32784       -1.32784
   0.420068       0.420068
  -0.720913      -0.720913
  -0.340982      -0.340982
   0.496067       0.496067
  -0.921807      -0.921807
  -1.92175       -1.92175
   0.59455        0.59455
   0.827755       0.827755
  -1.90727       -1.90727
   1.51996        1.51996
   1.79573        1.79573
  -2.10208       -2.10208
   4.78008        4.78008
   0.767953       0.767953
   0.240847       0.240847
   1.97272        1.97272
  -1.59962       -1.59962
  -1.47237       -1.47237
  -0.580724      -0.580724
   1.75388        1.75388
  -1.67413       -1.67413
  -0.636017      -0.636017
  -1.35096       -1.35096
   0.722983       0.722983
  -0.585923      -0.585923
  -0.529864      -0.529864
  -0.91566       -0.91566
   0.242429       0.242429
   0.236836       0.236836
  -1.78323       -1.78323
   0.716162       0.716162
   0.166974       0.166974
  -0.00891157    -0.00891157
   0.936227       0.936227
   0.992144       0.992144
   0.00694193     0.00694193
  -3.58995       -3.58995
  -2.90908       -2.90908
   2.30937        2.30937
  -0.504803      -0.504803
   0.870025       0.870025
   1.0472         1.0472
  -0.165569      -0.165569
  -0.110656      -0.110656
  -0.240613      -0.240613
   1.47692        1.47692
   0.153659       0.153659
   0.237772       0.237772
  -0.427641      -0.427641
  -1.6352        -1.6352
  -0.329495      -0.329495
   1.89567        1.89567
   0.500036       0.500036
   2.60672        2.60672
   1.08705        1.08705
   0.234073       0.234073
   1.80469        1.80469
   0.859386       0.859386
   1.59161        1.59161
  -1.25096       -1.25096
   0.693032       0.693032
  -0.208542      -0.208542
   2.9791         2.9791
   0.0637262      0.0637262
  -0.329288      -0.329288
   0.0765908      0.0765908
  -0.975783      -0.975783
   0.44728        0.44728
   0.158878       0.158878
  -1.23836       -1.23836
   0.670039       0.670039
  -0.0279593     -0.0279593
  -1.08503       -1.08503
  -1.61416       -1.61416
  -1.68594       -1.68594
   0.91421        0.91421
   0.164412       0.164412
  -0.452083      -0.452083
  -3.85434       -3.85434
  -1.17754       -1.17754
  -0.824006      -0.824006
   2.34023        2.34023
  -2.09985       -2.09985
   0.881987       0.881987
  -1.37035       -1.37035
   0.642559       0.642559
  -0.17144       -0.17144
   1.61998        1.61998
  -0.621223      -0.621223
  -3.74722       -3.74722
   1.14967        1.14967
   0.718755       0.718755
   0.675293       0.675293
  -1.53459       -1.53459
   0.521371       0.521371
  -0.0142472     -0.0142472
  -1.10933       -1.10933
  -1.60977       -1.60977
  -0.152616      -0.152616
   0.402871       0.402871
   0.929587       0.929587
   1.69781        1.69781
  -1.8187        -1.8187
   2.04684        2.04684
  -1.29619       -1.29619
  -0.212775      -0.212775
   1.52843        1.52843
  -1.69828       -1.69828
  -1.05251       -1.05251
   3.80258        3.80258
   1.77294        1.77294
   1.20703        1.20703
   0.81561        0.81561
   0.748058       0.748058
   1.45736        1.45736
   1.33881        1.33881
  -0.86026       -0.86026
  -0.00694993    -0.00694993
  -1.67171       -1.67171
  -2.64284       -2.64284
  -0.617916      -0.617916
  -0.658362      -0.658362
  -0.302764      -0.302764
  -0.218727      -0.218727
   2.68447        2.68447
   1.91834        1.91834
  -0.630305      -0.630305
  -0.483942      -0.483942
  -0.205622      -0.205622
   0.230539       0.230539
  -2.42183       -2.42183
   0.000632207    0.000632207
   1.22722        1.22722
   0.499288       0.499288
  -0.461535      -0.461535
  -2.41778       -2.41778
  -6.43109       -6.43109
   1.87164        1.87164
  -0.128426      -0.128426
   1.70185        1.70185
   0.321244       0.321244
  -2.8774        -2.8774
  -0.973839      -0.973839
  -1.78429       -1.78429
  -1.42296       -1.42296
  -2.18451       -2.18451
  -0.997205      -0.997205
  -2.09179       -2.09179
  -0.418012      -0.418012
  -3.86836       -3.86836
  -1.08119       -1.08119
  -2.73167       -2.73167
  -1.83625       -1.83625
   0.048819       0.048819
   1.82894        1.82894
   0.828514       0.828514
   0.392871       0.392871
   1.13363        1.13363
  -1.79231       -1.79231
   0.163824       0.163824
  -1.27652       -1.27652
   2.06888        2.06888
  -0.63393       -0.63393
   0.684518       0.684518
  -0.906544      -0.906544
  -0.987848      -0.987848
  -0.478984      -0.478984
  -1.2593        -1.2593
   2.07364        2.07364
   0.162523       0.162523
  -0.799031      -0.799031
  -0.299117      -0.299117
   0.0988399      0.0988399
  -0.238386      -0.238386
   3.0895         3.0895
   0.415509       0.415509
   1.50283        1.50283
  -0.561321      -0.561321
   2.24325        2.24325
  -0.490123      -0.490123
  -1.27889       -1.27889
   0.10889        0.10889
   0.581722       0.581722
  -0.657735      -0.657735
  -0.722435      -0.722435
  -1.3811        -1.3811
   1.5928         1.5928
  -9.72189       -9.72189
  -1.07349       -1.07349
  -1.25083       -1.25083
   0.919328       0.919328
  -1.9068        -1.9068
  -1.23178       -1.23178
  -0.782403      -0.782403
  -0.689571      -0.689571
  -2.07093       -2.07093
  -0.0676932     -0.0676932
  -1.47628       -1.47628
  -1.79765       -1.79765
   1.79051        1.79051
   0.410585       0.410585
  -1.41706       -1.41706
   1.64883        1.64883
  -0.528457      -0.528457
   0.193134       0.193134
  -0.989156      -0.989156
   3.3787         3.3787
   0.734755       0.734755
   1.20919        1.20919
   0.142022       0.142022
   0.950151       0.950151
  -2.14197       -2.14197
   2.91323        2.91323
  -0.216118      -0.216118
   1.18072        1.18072
  -5.00813       -5.00813
   1.22234        1.22234
  -2.40273       -2.40273
  -1.93511       -1.93511
   1.02775        1.02775
  -0.407362      -0.407362
  -0.033977      -0.033977
  -0.673432      -0.673432
  -0.395374      -0.395374
  -0.0686072     -0.0686072
   2.26745        2.26745
  -4.0298        -4.0298
   0.30017        0.30017
   0.576736       0.576736
   1.84158        1.84158
  -0.427059      -0.427059
  -3.47072       -3.47072
  -0.207896      -0.207896
   1.07928        1.07928
  -0.424236      -0.424236
  -0.809626      -0.809626
   2.48986        2.48986
  -0.808405      -0.808405
  -0.0510026     -0.0510026
  -0.919838      -0.919838
   1.44427        1.44427
   2.71946        2.71946
   0.0683191      0.0683191
  -1.08351       -1.08351
  -1.56937       -1.56937
   3.01879        3.01879
  -1.56172       -1.56172
   2.06467        2.06467
   2.03327        2.03327
  -0.81693       -0.81693
   0.922913       0.922913
   0.95788        0.95788
  -0.778203      -0.778203
   1.08222        1.08222
   1.44635        1.44635
  -1.75929       -1.75929
   0.112181       0.112181
   0.681292       0.681292
  -0.432171      -0.432171
   1.06316        1.06316
  -1.7268        -1.7268
  -3.37779       -3.37779
  -2.89964       -2.89964
   0.901763       0.901763
  -1.2757        -1.2757
 -12.5488       -12.5488
   2.55937        2.55937
  -1.79624       -1.79624
  -2.36511       -2.36511
   0.755598       0.755598
  -1.59443       -1.59443
  -3.05103       -3.05103
  -1.29157       -1.29157
   0.254057       0.254057
  -0.628874      -0.628874
  -0.119316      -0.119316
   4.96649        4.96649
  -1.36958       -1.36958
  -0.258365      -0.258365
   0.207744       0.207744
  -0.166113      -0.166113
  -1.22071       -1.22071
  -3.68573       -3.68573
  -3.16103       -3.16103
  -1.89154       -1.89154
   0.98744        0.98744
  -0.585739      -0.585739
  -1.99954       -1.99954
   2.03071        2.03071
   0.471045       0.471045
  -1.93214       -1.93214
  -0.825462      -0.825462
   0.497266       0.497266
  -0.563979      -0.563979
   1.69555        1.69555
   3.04967        3.04967
  -0.302795      -0.302795
   1.60455        1.60455
   2.28473        2.28473
  -1.28218       -1.28218
  -0.559678      -0.559678
  -0.759997      -0.759997
   0.809902       0.809902
  -0.451467      -0.451467
  -1.21982       -1.21982
   0.325713       0.325713
  -3.28885       -3.28885
  -0.124363      -0.124363
  -0.698127      -0.698127
  -0.213705      -0.213705
  -2.03161       -2.03161
   1.82803        1.82803
   0.644781       0.644781
   0.20483        0.20483
   4.57695        4.57695
  -2.63731       -2.63731
  -2.18961       -2.18961
  -2.48184       -2.48184
   0.0614645      0.0614645
   0.377704       0.377704
   2.34104        2.34104
   0.657159       0.657159
  -1.25309       -1.25309
  -2.45413       -2.45413
   1.88619        1.88619
   1.74094        1.74094
   2.3351         2.3351
   0.212613       0.212613
  -1.16212       -1.16212
   1.02027        1.02027
   0.0929927      0.0929927
   0.260815       0.260815
  -1.58322       -1.58322
  -1.5689        -1.5689
   1.90734        1.90734
  -0.398199      -0.398199
   1.1045         1.1045
  -1.90117       -1.90117
  -1.35457       -1.35457
  -0.904438      -0.904438
  -2.4261        -2.4261
   2.24749        2.24749
   0.293511       0.293511
  -1.96554       -1.96554
  -0.310607      -0.310607
   0.399931       0.399931
   1.06214        1.06214
   1.14559        1.14559
  -1.29189       -1.29189
   1.25441        1.25441
   2.97262        2.97262
  -1.02313       -1.02313
   1.05321        1.05321
  -0.804898      -0.804898
   3.63862        3.63862
   0.527294       0.527294
  -0.681347      -0.681347
   1.11035        1.11035
   2.40787        2.40787
   1.19095        1.19095
  -0.380581      -0.380581
   0.0582491      0.0582491
   0.264974       0.264974
   0.169384       0.169384
   1.4731         1.4731
   2.23289        2.23289
   0.191901       0.191901
  -2.60952       -2.60952
  -2.62244       -2.62244
   0.784122       0.784122
   2.74349        2.74349
  -0.155218      -0.155218
   0.967558       0.967558
   0.186159       0.186159
  -0.204567      -0.204567
  -0.606278      -0.606278
  -0.011704      -0.011704
   1.08489        1.08489
  -0.277437      -0.277437
   0.0090858      0.0090858
   0.258057       0.258057
  -0.373131      -0.373131
  -1.44058       -1.44058
  -1.01993       -1.01993
  -2.4798        -2.4798
   0.271599       0.271599
  -1.84189       -1.84189
  -0.490777      -0.490777
  -0.414488      -0.414488
  -1.07757       -1.07757
   1.23712        1.23712
  -2.02542       -2.02542
  -2.07667       -2.07667
   2.89555        2.89555
  -2.61436       -2.61436
  -0.469252      -0.469252
  -1.29202       -1.29202
  -0.646527      -0.646527
   0.00517958     0.00517958
   0.5503         0.5503
   1.06083        1.06083
  -0.324516      -0.324516
  -1.84483       -1.84483
  -0.574072      -0.574072
  -0.211102      -0.211102
  -0.585931      -0.585931
   0.854918       0.854918
  -1.33179       -1.33179
  -1.87131       -1.87131
   1.63465        1.63465
   0.904734       0.904734
  -1.27273       -1.27273
  -2.41944       -2.41944
   0.626935       0.626935
  -1.74987       -1.74987
  -3.06298       -3.06298
  -0.714794      -0.714794
  -1.00437       -1.00437
   0.197116       0.197116
   0.276584       0.276584
   0.163489       0.163489
   1.74588        1.74588
  -1.48997       -1.48997
   0.561946       0.561946
  -0.164713      -0.164713
  -1.79587       -1.79587
   0.681301       0.681301
  -0.303574      -0.303574
   0.695659       0.695659
   2.46479        2.46479
   2.98348        2.98348
   1.50751        1.50751
   0.531878       0.531878
  -1.00327       -1.00327
   1.42955        1.42955
   1.41544        1.41544
   0.631301       0.631301
   0.887182       0.887182
  -0.689095      -0.689095
   1.0004         1.0004
   1.73016        1.73016
   3.52498        3.52498
   2.04091        2.04091
   1.25617        1.25617
  -0.769574      -0.769574
  -0.439135      -0.439135
  -0.320473      -0.320473
   1.88776        1.88776
  -3.08042       -3.08042
   0.427227       0.427227
   1.32274        1.32274
  -2.11399       -2.11399
   3.3764         3.3764
  -0.943091      -0.943091
   2.07374        2.07374
  -1.59418       -1.59418
  -4.37112       -4.37112
   0.620227       0.620227
  -0.322782      -0.322782
   0.447005       0.447005
   0.280967       0.280967
   1.68907        1.68907
  -1.60102       -1.60102
   2.9697         2.9697
  -0.0128504     -0.0128504
  -0.782678      -0.782678
   0.397837       0.397837
  -0.159312      -0.159312
   1.14526        1.14526
   0.0428197      0.0428197
   1.77001        1.77001
   1.08919        1.08919
   0.55684        0.55684
   0.398568       0.398568
   1.27518        1.27518
  -1.85676       -1.85676
  -2.56394       -2.56394
  -0.357036      -0.357036
   2.1851         2.1851
  -1.03051       -1.03051
   0.922326       0.922326
   0.654941       0.654941
  -0.902982      -0.902982
  -0.90051       -0.90051
  -0.127011      -0.127011
   1.76007        1.76007
   0.424547       0.424547
  -1.13683       -1.13683
   1.83884        1.83884
  -0.918215      -0.918215
   0.658109       0.658109
  -0.365433      -0.365433
  -2.18908       -2.18908
  -1.93223       -1.93223
   0.408743       0.408743
  -1.92079       -1.92079
   0.0976185      0.0976185
   4.67569        4.67569
  -1.49021       -1.49021
   0.176745       0.176745
  -1.03095       -1.03095
  -2.1574        -2.1574
  -0.593898      -0.593898
   1.01641        1.01641
  -0.28545       -0.28545
  -2.17595       -2.17595
   1.00962        1.00962
   0.592646       0.592646
  -0.343818      -0.343818
  -0.440034      -0.440034
   1.38711        1.38711
  -1.43068       -1.43068
   0.681063       0.681063
  -1.94052       -1.94052
  -2.38281       -2.38281
  -0.789486      -0.789486
  -1.35709       -1.35709
  -1.69084       -1.69084
  -1.62863       -1.62863
  -0.284129      -0.284129
  -2.83546       -2.83546
  -0.915304      -0.915304
   0.257879       0.257879
   0.745803       0.745803
  -0.134261      -0.134261
  -0.00297398    -0.00297398
  -0.452233      -0.452233
  -2.36279       -2.36279
   1.21461        1.21461
  -1.13373       -1.13373
  -0.329279      -0.329279
  -1.64147       -1.64147
  -0.579568      -0.579568
  -0.783701      -0.783701
   0.606064       0.606064
   0.249187       0.249187
  -0.266901      -0.266901
   5.9043         5.9043
  -0.630335      -0.630335
  -0.37167       -0.37167
   2.66605        2.66605
  -1.36786       -1.36786
   0.452445       0.452445
  -1.28971       -1.28971
   2.37668        2.37668
   2.52488        2.52488
   0.142467       0.142467
   1.68463        1.68463
   1.30605        1.30605
  -3.62793       -3.62793
   2.48566        2.48566
  -1.13421       -1.13421
   0.0926649      0.0926649
  -3.63194       -3.63194
   0.108222       0.108222
  -1.92097       -1.92097
  -0.609085      -0.609085
  -2.23882       -2.23882
   1.30409        1.30409
   0.251002       0.251002
   0.820516       0.820516
   1.14979        1.14979
   4.24577        4.24577
   0.195344       0.195344
  -0.322737      -0.322737
   0.93393        0.93393
   2.81175        2.81175
   0.446439       0.446439
  -1.38935       -1.38935
   0.386624       0.386624
   0.464916       0.464916
  -1.58662       -1.58662
  -1.12035       -1.12035
   1.79443        1.79443
   1.03373        1.03373
   1.24398        1.24398
  -0.343199      -0.343199
   0.778172       0.778172
   3.7689         3.7689
   1.15726        1.15726
   0.0548858      0.0548858
   1.46606        1.46606
  -0.0390753     -0.0390753
   0.525417       0.525417
  -0.399366      -0.399366
  -0.389525      -0.389525
   1.53548        1.53548
  -0.660596      -0.660596
   1.02893        1.02893
   5.36388        5.36388
  -0.158376      -0.158376
  -0.00158735    -0.00158735
   1.48366        1.48366
   1.58287        1.58287
  -1.32445       -1.32445
   1.18222        1.18222
   0.859016       0.859016
  -0.366681      -0.366681
  -1.97608       -1.97608
  -1.60289       -1.60289
   0.801427       0.801427
   0.734912       0.734912
  -0.655545      -0.655545
  -3.4244        -3.4244
   1.79295        1.79295
   1.64987        1.64987
  -0.372111      -0.372111
  -0.818163      -0.818163
  -1.73224       -1.73224
   1.07321        1.07321
  -1.09122       -1.09122
  -2.31512       -2.31512
  -1.51542       -1.51542
  -0.366266      -0.366266
   2.78864        2.78864
  -1.79099       -1.79099
  -0.527644      -0.527644
   0.617675       0.617675
   0.817341       0.817341
  -1.59739       -1.59739
  -0.942853      -0.942853
  -0.024404      -0.024404
   0.838706       0.838706
   2.69883        2.69883
  -1.84305       -1.84305
   0.197916       0.197916
   1.40902        1.40902
   0.780807       0.780807
  -0.447145      -0.447145
   0.39841        0.39841
  -0.568937      -0.568937
   3.35843        3.35843
   0.244485       0.244485
  -0.409614      -0.409614
   1.79979        1.79979
  -0.114665      -0.114665
   2.12529        2.12529
  -1.1328        -1.1328
  -1.32568       -1.32568
  -1.33014       -1.33014
   0.61469        0.61469
   0.23576        0.23576
  -1.58669       -1.58669
   0.882018       0.882018
  -0.199537      -0.199537
   0.0213817      0.0213817
  -0.0526741     -0.0526741
  -1.90557       -1.90557
  -0.861437      -0.861437
  -1.73529       -1.73529
  -1.20074       -1.20074
   1.52766        1.52766
   0.229589       0.229589
   0.371437       0.371437
  -2.27666       -2.27666
   0.500965       0.500965
   0.342153       0.342153
   1.54886        1.54886
  -2.35151       -2.35151
   0.369683       0.369683
   0.537004       0.537004
   0.462267       0.462267
   0.104486       0.104486
   1.76568        1.76568
   0.66308        0.66308
  -0.610417      -0.610417
  -1.19933       -1.19933
   0.458763       0.458763
   1.12317        1.12317
   0.639384       0.639384
   0.420247       0.420247
  -0.516877      -0.516877
   1.85253        1.85253
  -1.28899       -1.28899
  -1.2008        -1.2008
   0.55433        0.55433
   0.209396       0.209396
  -1.13624       -1.13624
  -1.29488       -1.29488
  -0.990851      -0.990851
  -1.82754       -1.82754
  -1.10815       -1.10815
   0.268715       0.268715
  -1.8783        -1.8783
   1.46547        1.46547
   2.47695        2.47695
  -2.0124        -2.0124
  -2.23708       -2.23708
   2.61164        2.61164
   0.260522       0.260522
   0.570767       0.570767
   2.82558        2.82558
   1.21898        1.21898
  -2.1909        -2.1909
   1.95577        1.95577
  -0.334229      -0.334229
   0.490568       0.490568
   0.476326       0.476326
  -2.85789       -2.85789
  -1.67129       -1.67129
  -3.44224       -3.44224
   1.39022        1.39022
   1.13294        1.13294
   1.12937        1.12937
   1.55696        1.55696
   0.641922       0.641922
   3.02277        3.02277
   0.727429       0.727429
   2.29113        2.29113
  -0.345511      -0.345511
  -0.963097      -0.963097
   2.04846        2.04846
   1.82306        1.82306
  -0.10738       -0.10738
   1.47278        1.47278
   0.44212        0.44212
  -0.664988      -0.664988
  -0.522717      -0.522717
   0.015111       0.015111
  -1.17036       -1.17036
   0.533411       0.533411
  -0.755567      -0.755567
   1.3441         1.3441
   2.34532        2.34532
   1.54432        1.54432
   0.346052       0.346052
  -0.317292      -0.317292
  -0.419647      -0.419647
   0.778187       0.778187
   2.52819        2.52819
   1.71307        1.71307
   0.108402       0.108402
  -0.286356      -0.286356
  -0.184754      -0.184754
  -2.0023        -2.0023
  -1.88134       -1.88134
  -0.401823      -0.401823
  -0.103521      -0.103521
   0.753005       0.753005
  -0.803658      -0.803658
   2.44367        2.44367
   1.58612        1.58612
  -0.94574       -0.94574
   0.269329       0.269329
   2.60832        2.60832
  -0.113991      -0.113991
   2.23152        2.23152
  -1.14749       -1.14749
  -1.86227       -1.86227
  -2.06391       -2.06391
  -0.960271      -0.960271
  -0.953305      -0.953305
  -0.162597      -0.162597
   0.405977       0.405977
   1.18975        1.18975
  -2.68021       -2.68021
   0.557723       0.557723
   0.1416         0.1416
  -2.27623       -2.27623
  -0.91957       -0.91957
   1.4132         1.4132
   2.40127        2.40127
   0.364167       0.364167
   1.67016        1.67016
   0.345176       0.345176
  -0.885645      -0.885645
  -1.92508       -1.92508
  -0.527327      -0.527327
   0.59694        0.59694
  -0.928777      -0.928777
  -2.45285       -2.45285
   0.093849       0.093849
   0.875405       0.875405
   0.734934       0.734934
  -1.58165       -1.58165
  -0.43735       -0.43735
   0.103331       0.103331
   1.57271        1.57271
  -0.670804      -0.670804
   3.11503        3.11503
   2.03147        2.03147
  -1.12063       -1.12063
   1.76581        1.76581
  -1.91044       -1.91044
  -0.334989      -0.334989
  -0.115597      -0.115597
   2.82           2.82
   2.8363         2.8363
  -2.12753       -2.12753
   0.551957       0.551957
   0.778678       0.778678
   0.26151        0.26151
   0.527825       0.527825
  -1.24336       -1.24336
  -1.28699       -1.28699
  -0.227357      -0.227357
   4.99396        4.99396
  -1.90422       -1.90422
  -0.883407      -0.883407
   3.10147        3.10147
   0.33776        0.33776
   0.12595        0.12595
  -0.147078      -0.147078
   0.40136        0.40136
   0.092439       0.092439
  -0.903678      -0.903678
   0.786246       0.786246
   1.43764        1.43764
  -4.39428       -4.39428
   1.17994        1.17994
   0.485781       0.485781
   1.63216        1.63216
  -1.36006       -1.36006
   0.773674       0.773674
   0.618503       0.618503
  -0.0300672     -0.0300672
   0.484393       0.484393
  -0.874462      -0.874462
  -2.0849        -2.0849
  -0.576099      -0.576099
   0.765223       0.765223
  -3.83117       -3.83117
   1.46556        1.46556
   1.88278        1.88278
   3.49482        3.49482
   2.57193        2.57193
  -3.45378       -3.45378
   0.101699       0.101699
  -0.67995       -0.67995
  -1.76783       -1.76783
   1.16307        1.16307
  -0.258105      -0.258105
   1.91705        1.91705
  -2.29152       -2.29152
   0.348873       0.348873
  -0.74269       -0.74269
   0.158894       0.158894
  -0.454844      -0.454844
   2.23608        2.23608
  -0.210747      -0.210747
  -0.544031      -0.544031
   0.656622       0.656622
  -1.47574       -1.47574
   0.0299864      0.0299864
   1.77173        1.77173
  -2.23061       -2.23061
  -1.00651       -1.00651
  -0.0842836     -0.0842836
  -1.17457       -1.17457
   3.36571        3.36571
   0.656163       0.656163
  -0.0818359     -0.0818359
   2.36086        2.36086
  -2.1491        -2.1491
   1.45799        1.45799
  -1.09112       -1.09112
   1.1336         1.1336
   0.414929       0.414929
   1.73283        1.73283
   0.333332       0.333332
   0.612909       0.612909
   2.27707        2.27707
 -17.3366       -17.3366
  -0.706549      -0.706549
   0.569747       0.569747
  -2.88274       -2.88274
  -0.39159       -0.39159
  -1.272         -1.272
   1.8522         1.8522
   2.84343        2.84343
  -0.497109      -0.497109
   0.712927       0.712927
  -0.454025      -0.454025
   0.26183        0.26183
   1.70567        1.70567
   2.65185        2.65185
   0.0631512      0.0631512
   1.55346        1.55346
   1.88528        1.88528
   0.550265       0.550265
  -0.663944      -0.663944
   0.796127       0.796127
   1.5298         1.5298
  -0.619118      -0.619118
   0.718367       0.718367
  -1.1251        -1.1251
  -0.162817      -0.162817
   0.158565       0.158565
  -0.479435      -0.479435
   0.39778        0.39778
  -0.0668922     -0.0668922
  -0.554059      -0.554059
  -0.112442      -0.112442
   0.723476       0.723476
   0.585585       0.585585
 -23.8354       -23.8354
   2.23005        2.23005
   3.19716        3.19716
   0.878244       0.878244
   1.24065        1.24065
   2.02788        2.02788
   1.33889        1.33889
  -0.0959704     -0.0959704
   0.819301       0.819301
   1.13624        1.13624
  -3.73236       -3.73236
  -0.228297      -0.228297
   0.300764       0.300764
   2.44121        2.44121
   1.64459        1.64459
  -2.9741        -2.9741
  -0.0767092     -0.0767092
   1.18346        1.18346
   0.766311       0.766311
  -2.34982       -2.34982
  -1.19871       -1.19871
  -1.12327       -1.12327
  -1.51106       -1.51106
  -0.954545      -0.954545
   1.09042        1.09042
   1.78073        1.78073
  -1.6752        -1.6752
   0.032185       0.032185
  -0.67565       -0.67565
  -0.318844      -0.318844
  -2.8893        -2.8893
  -0.0509838     -0.0509838
  -1.21507       -1.21507
   2.30929        2.30929
   0.216374       0.216374
   1.31134        1.31134
  -0.0998794     -0.0998794
   1.20712        1.20712
  -0.650083      -0.650083
   0.399312       0.399312
  -0.983942      -0.983942
  -1.13459       -1.13459
  -1.05734       -1.05734
  -1.5015        -1.5015
  -1.77513       -1.77513
  -1.40363       -1.40363
   1.33786        1.33786
  -0.826259      -0.826259
   1.47633        1.47633
  -0.943677      -0.943677
  -1.46965       -1.46965
  -0.526938      -0.526938
   0.191906       0.191906
  -0.886405      -0.886405
   0.449917       0.449917
   0.515804       0.515804
  -1.39774       -1.39774
  -0.654256      -0.654256
  -3.35005       -3.35005
   2.06083        2.06083
  -0.704538      -0.704538
  -0.462466      -0.462466
  -2.67366       -2.67366
  -2.18423       -2.18423
  -2.64621       -2.64621
   0.763978       0.763978
  -2.66418       -2.66418
  -1.60911       -1.60911
   2.16377        2.16377
   0.0968811      0.0968811
   1.1338         1.1338
   1.00793        1.00793
   1.46003        1.46003
  -1.83402       -1.83402
   0.91668        0.91668
   0.614564       0.614564
   0.635087       0.635087
  -1.34331       -1.34331
  -0.972611      -0.972611
   0.674227       0.674227
  -0.667037      -0.667037
  -2.53443       -2.53443
  -1.53923       -1.53923
  -0.503973      -0.503973
  -3.74964       -3.74964
  -2.319         -2.319
   0.634011       0.634011
  -0.232782      -0.232782
   0.494076       0.494076
  -1.22967       -1.22967
   2.0448         2.0448
  -2.49856       -2.49856
   0.234543       0.234543
   0.926016       0.926016
   0.556234       0.556234
   1.40825        1.40825
  -0.0225873     -0.0225873
   0.584709       0.584709
   0.750481       0.750481
   0.548451       0.548451
  -0.50962       -0.50962
   1.37736        1.37736
  -0.205268      -0.205268
  -2.18919       -2.18919
  -1.09548       -1.09548
   2.88677        2.88677
   0.36593        0.36593
   1.59942        1.59942
   2.36871        2.36871
  -0.360048      -0.360048
   0.462762       0.462762
  -2.94594       -2.94594
  -1.04354       -1.04354
   0.866209       0.866209
   1.5211         1.5211
   1.06147        1.06147
   0.900548       0.900548
  -2.17463       -2.17463
   2.6977         2.6977
  -0.854358      -0.854358
   1.45336        1.45336
   0.700988       0.700988
  -1.89129       -1.89129
   0.346364       0.346364
   1.09519        1.09519
   1.19629        1.19629
  -0.193888      -0.193888
   3.33354        3.33354
  -0.986782      -0.986782
  -0.328471      -0.328471
   1.29318        1.29318
   0.463316       0.463316
  -1.3053        -1.3053
  -0.247824      -0.247824
   0.770688       0.770688
  -0.471133      -0.471133
   0.613311       0.613311
  -0.394463      -0.394463
  -1.93519       -1.93519
  -1.45159       -1.45159
   0.868683       0.868683
   2.57851        2.57851
  -2.39077       -2.39077
   1.63547        1.63547
  -0.0639398     -0.0639398
   1.19782        1.19782
  -1.83348       -1.83348
  -0.473202      -0.473202
   0.124168       0.124168
   1.16798        1.16798
   1.21296        1.21296
  -0.527453      -0.527453
  -1.20688       -1.20688
  -0.713952      -0.713952
   0.262652       0.262652
  -2.18811       -2.18811
   4.102          4.102
   0.494994       0.494994
   2.77783        2.77783
   1.07731        1.07731
   0.198336       0.198336
   9.57229        9.57229
   0.349448       0.349448
  -2.29562       -2.29562
  -0.644837      -0.644837
  -0.217495      -0.217495
  -1.45496       -1.45496
  -2.09866       -2.09866
  -0.0384889     -0.0384889
   0.745561       0.745561
   0.14508        0.14508
  -1.51823       -1.51823
  -3.26751       -3.26751
   0.0523259      0.0523259
   1.55301        1.55301
  -3.45208       -3.45208
   0.572187       0.572187
  -2.49679       -2.49679
   2.37328        2.37328
   0.765015       0.765015
  -0.27352       -0.27352
   0.0308149      0.0308149
  -0.593623      -0.593623
  -1.2373        -1.2373
  -0.656835      -0.656835
  -2.13627       -2.13627
   0.352383       0.352383
  -0.406136      -0.406136
   1.4126         1.4126
   1.98515        1.98515
   0.606976       0.606976
   0.788446       0.788446
   0.16519        0.16519
   0.596765       0.596765
  -0.873611      -0.873611
  -1.43965       -1.43965
   0.0971001      0.0971001
   3.33849        3.33849
   4.49406        4.49406
   1.91075        1.91075
   2.4465         2.4465
   2.35879        2.35879
  -2.22234       -2.22234
   2.1624         2.1624
   0.037742       0.037742
  -1.28695       -1.28695
   0.341673       0.341673
   1.11316        1.11316
   1.57437        1.57437
  -0.778719      -0.778719
  -2.35793       -2.35793
  -0.95091       -0.95091
  -1.59879       -1.59879
  -1.65049       -1.65049
   1.05626        1.05626
   1.14966        1.14966
  -2.68582       -2.68582
  -1.96644       -1.96644
   0.950004       0.950004
   3.03491        3.03491
  -1.64747       -1.64747
  -2.14413       -2.14413
  -0.804942      -0.804942
   2.19513        2.19513
   0.789969       0.789969
  -0.899571      -0.899571
  -0.190668      -0.190668
   0.600747       0.600747
   1.16949        1.16949
  -1.37309       -1.37309
  -1.43457       -1.43457
   0.462702       0.462702
   1.40818        1.40818
  -0.665746      -0.665746
  -2.68812       -2.68812
  -0.0352648     -0.0352648
  -1.20922       -1.20922
  -0.577064      -0.577064
  -1.71517       -1.71517
   1.35121        1.35121
   1.4034         1.4034
  -4.70048       -4.70048
  -4.44732       -4.44732
   0.136732       0.136732
   2.41848        2.41848
  -4.30087       -4.30087
  -2.46922       -2.46922
   0.376919       0.376919
   1.9388         1.9388
   1.19049        1.19049
   1.97452        1.97452
  -0.172176      -0.172176
  -2.31517       -2.31517
   7.36023        7.36023
  -0.738473      -0.738473
   0.0146472      0.0146472
   0.14857        0.14857
   2.47231        2.47231
   2.18251        2.18251
  -2.32425       -2.32425
  -2.17348       -2.17348
   7.06046        7.06046
   1.42047        1.42047
  -1.54418       -1.54418
  -0.469984      -0.469984
   1.63989        1.63989
   0.346456       0.346456
   1.15453        1.15453
  -0.441885      -0.441885
   0.183807       0.183807
   3.1971         3.1971
  -0.647559      -0.647559
   0.00128156     0.00128156
  -0.288304      -0.288304
   2.59287        2.59287
   1.19027        1.19027
   0.797827       0.797827
   1.09197        1.09197
   0.43136        0.43136
   0.380913       0.380913
  -1.74969       -1.74969
   1.14465        1.14465
  -0.386246      -0.386246
   0.566953       0.566953
   0.00563241     0.00563241
   0.841304       0.841304
   1.16119        1.16119
  -0.473218      -0.473218
   0.567447       0.567447
  -2.51315       -2.51315
   0.857171       0.857171
  -1.81643       -1.81643
   1.81088        1.81088
   1.49892        1.49892
  -0.900041      -0.900041
  -0.0992927     -0.0992927
   0.635308       0.635308
   0.0198956      0.0198956
   2.37949        2.37949
  -1.77301       -1.77301
  -0.716384      -0.716384
   0.226013       0.226013
  -3.16016       -3.16016
   0.470524       0.470524
   0.11595        0.11595
  -2.40913       -2.40913
  -0.394387      -0.394387
  -0.712704      -0.712704
   0.539429       0.539429
   2.49816        2.49816
  -0.611206      -0.611206
  -0.562752      -0.562752
  -0.835585      -0.835585
   3.25424        3.25424
  -0.480187      -0.480187
   5.29497        5.29497
  -2.8016        -2.8016
   0.0118055      0.0118055
   1.86542        1.86542
   0.101613       0.101613
  -2.00855       -2.00855
   0.771721       0.771721
  -0.0705836     -0.0705836
  -0.722898      -0.722898
   0.11892        0.11892
  -1.12107       -1.12107
   0.23499        0.23499
  -3.2635        -3.2635
   0.774997       0.774997
   3.05413        3.05413
   2.52668        2.52668
  -0.733611      -0.733611
  -0.465726      -0.465726
   1.61462        1.61462
  -0.297293      -0.297293
   0.247443       0.247443
   0.451474       0.451474
  -2.18135       -2.18135
  -0.253176      -0.253176
  -1.77935       -1.77935
   1.96681        1.96681
  -2.6561        -2.6561
  -0.98605       -0.98605
   3.74766        3.74766
  -1.86272       -1.86272
  -1.6491        -1.6491
   1.43297        1.43297
   3.00856        3.00856
  -2.91703       -2.91703
   2.31349        2.31349
   0.612495       0.612495
   0.303318       0.303318
   0.96081        0.96081
   0.401881       0.401881
  -0.130979      -0.130979
  -0.660971      -0.660971
   0.39712        0.39712
  -1.30811       -1.30811
   1.66804        1.66804
  -0.362844      -0.362844
  -3.37322       -3.37322
  -0.898031      -0.898031
  -2.35764       -2.35764
   0.234687       0.234687
   0.776599       0.776599
  -0.030942      -0.030942
  -3.49072       -3.49072
  -0.354064      -0.354064
   0.254806       0.254806
   0.413767       0.413767
  -2.23448       -2.23448
  -3.00986       -3.00986
  -3.03087       -3.03087
   1.22426        1.22426
  -0.00528415    -0.00528415
   1.63329        1.63329
  -3.00948       -3.00948
   0.544208       0.544208
  -2.26614       -2.26614
   0.202507       0.202507
   1.10992        1.10992
  -1.14457       -1.14457
   0.223205       0.223205
  -2.11668       -2.11668
   0.939281       0.939281
  -1.74119       -1.74119
   1.36972        1.36972
  -1.02231       -1.02231
   0.760286       0.760286
   1.4837         1.4837
   2.29908        2.29908
   1.30551        1.30551
  -0.294187      -0.294187
  -1.49058       -1.49058
   0.292385       0.292385
  -1.13357       -1.13357
  -0.90415       -0.90415
   0.874832       0.874832
   1.10395        1.10395
   2.24293        2.24293
  -1.39277       -1.39277
  -1.87169       -1.87169
  -0.0884342     -0.0884342
   0.167855       0.167855
   1.65614        1.65614
   1.8828         1.8828
   0.115504       0.115504
   4.08686        4.08686
  -0.626715      -0.626715
  -0.0646496     -0.0646496
   0.178995       0.178995
   1.50054        1.50054
   1.85495        1.85495
   1.94429        1.94429
   0.0459594      0.0459594
  -1.9626        -1.9626
  -1.70859       -1.70859
  -1.05544       -1.05544
   0.331346       0.331346
   0.698268       0.698268
  -1.06962       -1.06962
  -2.22214       -2.22214
   1.438          1.438
   1.93536        1.93536
  -0.429009      -0.429009
  -1.04787       -1.04787
  -1.8681        -1.8681
  -1.46553       -1.46553
  -0.704678      -0.704678
  -1.80182       -1.80182
  -0.954295      -0.954295
  -2.80916       -2.80916
  -1.25241       -1.25241
  -0.581477      -0.581477
   1.11401        1.11401
  -0.206182      -0.206182
  -0.0337333     -0.0337333
  -0.192489      -0.192489
  -0.602529      -0.602529
  -0.465761      -0.465761
   0.886887       0.886887
  -1.47977       -1.47977
   0.81157        0.81157
  -4.08164       -4.08164
  -0.650256      -0.650256
  -0.239842      -0.239842
  -0.376812      -0.376812
   0.608583       0.608583
   3.24043        3.24043
  -2.40365       -2.40365
  -2.12369       -2.12369
  -2.85674       -2.85674
  -1.11819       -1.11819
  -0.183936      -0.183936
  -1.38699       -1.38699
   0.63657        0.63657
   3.24116        3.24116
  -0.0696033     -0.0696033
   1.67356        1.67356
  -0.111105      -0.111105
   0.928557       0.928557
  -1.21476       -1.21476
   1.87918        1.87918
  -0.538827      -0.538827
  -1.96541       -1.96541
  -2.25371       -2.25371
   1.95748        1.95748
  -0.19679       -0.19679
  -0.139908      -0.139908
   0.621337       0.621337
  -0.019154      -0.019154
   0.701629       0.701629
   0.374446       0.374446
  -1.25937       -1.25937
   1.34433        1.34433
  -0.922861      -0.922861
   2.90885        2.90885
  -2.56409       -2.56409
  -0.256198      -0.256198
  -0.460552      -0.460552
   0.178514       0.178514
   0.182276       0.182276
   0.646096       0.646096
  -1.0186        -1.0186
   0.979231       0.979231
   1.84611        1.84611
   2.91017        2.91017
   0.327271       0.327271
   0.454179       0.454179
   1.09265        1.09265
  -0.143546      -0.143546
   0.846766       0.846766
   0.719947       0.719947
  -1.76553       -1.76553
   3.30387        3.30387
   0.321026       0.321026
   0.201893       0.201893
   2.04676        2.04676
   0.304647       0.304647
  -0.753991      -0.753991
  -1.40742       -1.40742
  -0.77855       -0.77855
   0.29947        0.29947
  -0.920328      -0.920328
  -0.463037      -0.463037
  -1.81857       -1.81857
  -0.305488      -0.305488
   1.80501        1.80501
  -2.63795       -2.63795
  -1.81647       -1.81647
  -2.82112       -2.82112
   0.773168       0.773168
   0.275974       0.275974
   0.0240539      0.0240539
  -0.764899      -0.764899
   1.05992        1.05992
  -0.84197       -0.84197
   1.27771        1.27771
   0.71536        0.71536
  -0.970194      -0.970194
  -2.22678       -2.22678
  -1.18751       -1.18751
   2.08652        2.08652
  -1.77634       -1.77634
   0.330371       0.330371
  -0.459388      -0.459388
   3.26156        3.26156
  -0.801958      -0.801958
   0.507587       0.507587
   0.0705198      0.0705198
  -4.27573       -4.27573
   1.35474        1.35474
  -0.563817      -0.563817
  -0.036168      -0.036168
   0.373159       0.373159
   0.146304       0.146304
   0.540254       0.540254
  -1.32898       -1.32898
   0.0550983      0.0550983
  -0.894857      -0.894857
   0.879887       0.879887
  -1.01703       -1.01703
   0.262536       0.262536
   0.605519       0.605519
  -0.682249      -0.682249
  -1.76663       -1.76663
   0.425809       0.425809
  -1.77275       -1.77275
  -2.40044       -2.40044
  -1.28476       -1.28476
  -1.80539       -1.80539
   3.42497        3.42497
  -0.737508      -0.737508
   1.09345        1.09345
   0.473303       0.473303
   0.569697       0.569697
   0.1682         0.1682
   1.14317        1.14317
  -0.305234      -0.305234
  -0.0553584     -0.0553584
   0.553831       0.553831
   2.72079        2.72079
  -1.11628       -1.11628
  -0.897232      -0.897232
   1.24584        1.24584
   0.407171       0.407171
  -0.548786      -0.548786
  -0.799434      -0.799434
  -0.337201      -0.337201
   1.38839        1.38839
  -2.03675       -2.03675
  -0.451153      -0.451153
  -1.51334       -1.51334
   0.99722        0.99722
  -0.952379      -0.952379
  -1.8534        -1.8534
   0.427123       0.427123
  -0.813837      -0.813837
   1.34476        1.34476
  -0.0132453     -0.0132453
   1.59654        1.59654
   1.28669        1.28669
  -0.262967      -0.262967
   0.319661       0.319661
   0.514152       0.514152
   8.72845        8.72845
   0.981584       0.981584
   2.1889         2.1889
   2.59352        2.59352
   4.8238         4.8238
  -1.98665       -1.98665
  -3.87038       -3.87038
   0.451746       0.451746
  -2.04906       -2.04906
   0.192938       0.192938
   1.08472        1.08472
  -0.548332      -0.548332
  -0.871136      -0.871136
   2.97136        2.97136
   0.822154       0.822154
  -1.43775       -1.43775
  -1.05529       -1.05529
   0.332036       0.332036
  -1.01064       -1.01064
   1.01202        1.01202
   0.603861       0.603861
   1.44141        1.44141
  -0.0347525     -0.0347525
  -2.645         -2.645
  -2.77208       -2.77208
   2.51425        2.51425
  -1.59414       -1.59414
   2.38812        2.38812
  -0.515258      -0.515258
  -1.70386       -1.70386
   0.740403       0.740403
  -0.519196      -0.519196
   3.56872        3.56872
   2.61736        2.61736
   0.921465       0.921465
   0.435321       0.435321
  -0.620441      -0.620441
   2.59352        2.59352
  -1.05395       -1.05395
   2.66575        2.66575
  -0.144386      -0.144386
   1.83629        1.83629
  -0.66284       -0.66284
   0.456305       0.456305
   2.47313        2.47313
  -0.947016      -0.947016
   0.201143       0.201143
   0.489325       0.489325
   1.87943        1.87943
   0.317216       0.317216
   1.68371        1.68371
  -1.48571       -1.48571
   1.8859         1.8859
   0.964108       0.964108
   3.81978        3.81978
   1.57192        1.57192
   3.67288        3.67288
   0.946176       0.946176
   1.40396        1.40396
   0.7311         0.7311
   1.83264        1.83264
   1.88672        1.88672
  -1.65002       -1.65002
  -1.27921       -1.27921
   0.328562       0.328562
  -1.67421       -1.67421
   1.5893         1.5893
  -0.871527      -0.871527
   2.71922        2.71922
   2.10276        2.10276
  -0.53672       -0.53672
   1.90948        1.90948
  -1.04531       -1.04531
   0.536989       0.536989
   0.0668934      0.0668934
   2.15979        2.15979
  -1.34284       -1.34284
   2.87173        2.87173
  -1.23698       -1.23698
   1.12051        1.12051
  -0.241109      -0.241109
  -1.84701       -1.84701
  -1.19951       -1.19951
  -1.08058       -1.08058
   0.412929       0.412929
  -0.620347      -0.620347
   3.21218        3.21218
   0.266479       0.266479
   0.999923       0.999923
   0.151579       0.151579
   0.0457301      0.0457301
  -0.863071      -0.863071
   0.650015       0.650015
  -0.724167      -0.724167
   0.943086       0.943086
  -2.67036       -2.67036
   0.592203       0.592203
  -1.73829       -1.73829
  -0.439297      -0.439297
   0.35609        0.35609
  -0.415771      -0.415771
   0.226092       0.226092
   1.98817        1.98817
  -2.98191       -2.98191
  -0.157906      -0.157906
  -0.0408938     -0.0408938
   1.32982        1.32982
  -1.98093       -1.98093
   1.68608        1.68608
   1.42987        1.42987
  -0.506031      -0.506031
  -3.44969       -3.44969
  -0.670397      -0.670397
   0.00317784     0.00317784
  -2.44821       -2.44821
  -0.973505      -0.973505
  -2.01111       -2.01111
   0.0882928      0.0882928
  -1.30306       -1.30306
   0.606925       0.606925
  -2.90382       -2.90382
   2.34368        2.34368
   1.06742        1.06742
  -0.147726      -0.147726
  -0.644699      -0.644699
   2.38565        2.38565
   0.423195       0.423195
  -2.39995       -2.39995
   3.07238        3.07238
   1.89833        1.89833
   2.6225         2.6225
  -0.520012      -0.520012
   2.15609        2.15609
  -3.67348       -3.67348
  -0.0497026     -0.0497026
   2.84596        2.84596
   0.620075       0.620075
  -0.554731      -0.554731
   2.15651        2.15651
  -0.754285      -0.754285
  -0.205464      -0.205464
  -0.530061      -0.530061
   1.06215        1.06215
  -0.484595      -0.484595
   0.527476       0.527476
   2.19013        2.19013
  -2.27807       -2.27807
  -0.523498      -0.523498
   1.80502        1.80502
   2.36156        2.36156
  -0.482968      -0.482968
  -1.094         -1.094
  -1.03241       -1.03241
   1.35803        1.35803
   2.60347        2.60347
   0.971085       0.971085
   0.552662       0.552662
  -0.776221      -0.776221
   0.828938       0.828938
   1.69376        1.69376
  -0.0488535     -0.0488535
   0.585078       0.585078
  -0.783814      -0.783814
   3.78798        3.78798
  -0.977169      -0.977169
  -0.699405      -0.699405
  -1.00392       -1.00392
   1.78081        1.78081
   0.846007       0.846007
  -1.53142       -1.53142
  -0.278166      -0.278166
  -1.7533        -1.7533
  -1.5105        -1.5105
  -0.911813      -0.911813
  -2.28061       -2.28061
   1.55691        1.55691
   0.119324       0.119324
  -1.75206       -1.75206
   1.31127        1.31127
  -1.10018       -1.10018
   1.50646        1.50646
   0.671974       0.671974
   0.408163       0.408163
  -2.99704       -2.99704
  -0.397517      -0.397517
   1.10579        1.10579
   0.309227       0.309227
   0.211714       0.211714
  -1.84012       -1.84012
  -0.727436      -0.727436
   2.11426        2.11426
   1.31798        1.31798
  -0.253154      -0.253154
   1.98683        1.98683
  -0.523705      -0.523705
   0.645383       0.645383
   4.59945        4.59945
  -0.753718      -0.753718
  -2.0014        -2.0014
  -2.86775       -2.86775
  -0.51614       -0.51614
   3.9091         3.9091
   2.32844        2.32844
  -1.42046       -1.42046
   2.29523        2.29523
   0.966474       0.966474
   0.938259       0.938259
   0.314803       0.314803
  -0.965298      -0.965298
   1.36128        1.36128
   2.32066        2.32066
   1.15654        1.15654
   0.208872       0.208872
  -0.40363       -0.40363
  -2.79805       -2.79805
  -1.10689       -1.10689
   1.06074        1.06074
   2.46081        2.46081
  -3.64489       -3.64489
   0.0728799      0.0728799
   1.73179        1.73179
  -0.529045      -0.529045
   0.661595       0.661595
  -1.01312       -1.01312
   1.3391         1.3391
   0.30467        0.30467
   2.72219        2.72219
   4.78742        4.78742
  -3.13914       -3.13914
   1.88923        1.88923
   2.43035        2.43035
   0.547254       0.547254
   0.406615       0.406615
  -3.88793       -3.88793
  -0.369601      -0.369601
  -0.868166      -0.868166
  -1.47208       -1.47208
  -0.294463      -0.294463
  -1.52052       -1.52052
  -1.18209       -1.18209
   0.554649       0.554649
   0.517766       0.517766
  -1.10023       -1.10023
   1.65443        1.65443
   2.07565        2.07565
  -0.788139      -0.788139
   1.2133         1.2133
  -0.364007      -0.364007
   1.45819        1.45819
   2.62594        2.62594
  -3.35007       -3.35007
  -0.143461      -0.143461
   0.21478        0.21478
   0.800875       0.800875
  -0.329759      -0.329759
   1.33073        1.33073
   0.147415       0.147415
  -1.57766       -1.57766
   0.151905       0.151905
   1.63538        1.63538
  -0.0241539     -0.0241539
   0.674812       0.674812
   0.0364426      0.0364426
   0.470479       0.470479
   0.617235       0.617235
   0.941854       0.941854
  -0.39178       -0.39178
  -3.72198       -3.72198
   0.249689       0.249689
   0.790793       0.790793
````

### Using postprocessing function
Add normalization as postprocessing function to normalize embeddings on reception (for easy cosine similarity later)

````julia
using LinearAlgebra
schema = PT.OllamaManagedSchema()

msg = aiembed(schema,
    ["embed me", "and me too"],
    LinearAlgebra.normalize;
    model = "openhermes2.5-mistral")
````

````
PromptingTools.DataMessage(Matrix{Float64} of size (4096, 2))
````

Cosine similarity is then a simple multiplication

````julia
msg.content' * msg.content[:, 1]
````

````
2-element Vector{Float64}:
 0.9999999999999982
 0.40796033843072876
````

---

*This page was generated using [Literate.jl](https://github.com/fredrikekre/Literate.jl).*

